# Electing Local Election Officials Replication Code: Data Analysis - Figures
library(tidyverse); library(RColorBrewer); library(usdata); library(gsynth)
library(data.table); library(did); library(fixest); library(maps); library(mapproj)

dat <- read.csv("../dat.csv")
path <- getwd()

# Figure 1: Local Election Administration Selection Methods, 1960-2022
## Set up the administrative data
datmap <- dat %>% 
  select(state, county, fips, appoint_to_elect, elect_to_appoint, always_appointed,
         always_elected, multiple_switches, ever_divided, cohort) %>% 
  group_by(fips) %>% 
  slice(1) %>% 
  rename(region = state,
         subregion=county) %>% 
  mutate(region = str_to_lower(region),
         subregion = str_to_lower(subregion),
         subregion = case_when(
           subregion == "dekalb" & region == "georgia" ~ "de kalb",
           subregion=="dekalb" & region=="illinois" ~ "de kalb",
           subregion=="dewitt" & region=="illinois" ~ "de witt",
           subregion=="dupage" & region=="illinois" ~ "du page",
           subregion=="lasalle" & region=="illinois" ~ "la salle",
           subregion == "st. clair" & region == "illinois" ~ "st clair",
           subregion == "dekalb" & region == "indiana" ~ "de kalb",
           subregion == "st. joseph" & region == "indiana" ~ "	st joseph",
           subregion == "st. louis" & region == "minnesota" ~ "st louis",
           subregion=="dekalb" & region=="missouri" ~ "de kalb",
           subregion == "st. charles" & region == "missouri" ~ "st charles",
           subregion == "st. clair" & region == "missouri" ~ "st clair",
           subregion == "ste. genevieve" & region == "missouri" ~ "ste genevieve",
           subregion == "st. francois" & region == "missouri" ~ "st francois",
           subregion =="st. louis" & region == "missouri" ~ "st louis",
           subregion == "st. louis city" & region == "missouri" ~ "st louis city",
           subregion =="dewitt" & region =="texas" ~ "de witt",
           TRUE ~ subregion))

## Set up the county boundaries with county type data
map_counties = map_data('county') %>%
  left_join(datmap, by=c("region", "subregion")) %>%
  mutate(county_type = case_when(
    is.na(appoint_to_elect) ~ "Not in Scope",
    ever_divided == 1 ~ "Not in Scope",
    always_appointed == 1 ~ "Always appointed",
    always_elected == 1 & subregion != "loving" ~ "Always elected",
    appoint_to_elect == 1 & multiple_switches == 0 ~ "Appointed to elected",
    elect_to_appoint == 1 & multiple_switches == 0 ~ "Elected to appointed",
    multiple_switches == 1 ~ "Multiple switches",
    subregion == "loving" ~ "Not in Scope",
    TRUE ~ "Not in Scope"))

## Set up the state boundaries
map_states = map_data('state') %>%
  filter(!(region %in% c("alaska", "hawaii")))

## Define the colors for the map
colors_base = brewer.pal(9, 'Blues')
map_colors = colors_base
map_colors[1] = colors_base[1]
map_colors[2] = colors_base[3]
map_colors[3] = colors_base[5]
map_colors[4] = colors_base[7]
map_colors[5] = colors_base[9]
map_colors[6] = 'lightgray'

## Make and save the map
map = ggplot() +
  geom_polygon(data=map_counties, aes(x = long, y = lat, 
                                      group = group, fill = county_type),
               color = '#616161', size = .1) +
  geom_polygon(data=map_states, aes(x = long, y = lat, group=group),
               fill=NA, color = '#444444', size = .3) + 
  coord_map("albers", lat0=39, lat1=45) +
  theme_void() + 
  guides(fill = guide_legend(title = '', title.position = 'top')) +
  scale_fill_manual(values = map_colors) +
  theme(legend.position = 'bottom',
        legend.title = element_text(color = 'black', size = 25),
        legend.text = element_text(size = 25),
        legend.key.size = unit(1.15, 'cm'))
ggsave("../output/figures/Figure_1.pdf", map, width=15, height=9)


# Figure 2: Local Election Administration Selection Cohorts, 1960-2022
## Run lines 10--37 above first

map_counties = map_data('county') %>%
  left_join(datmap, by=c("region", "subregion")) %>% 
  mutate(county_type = case_when(
    cohort == 0 ~ "Always Elected",
    cohort == 1960 ~ "Always Appointed",
    is.na(cohort) ~ "Not in Scope",
    TRUE ~ as.character(cohort)))

# Set up the state boundaries
map_states = map_data('state') %>%
  filter(!(region %in% c("alaska", "hawaii")))

# Define the colors for the map
colors_base = brewer.pal(4, 'PuOr')
colors_base = colorRampPalette(colors_base)(32)
map_colors = colors_base
map_colors[1] = colors_base[2]
map_colors[2] = colors_base[3]
map_colors[3] = colors_base[4]
map_colors[4] = colors_base[5]
map_colors[5] = colors_base[6]
map_colors[6] = colors_base[7]
map_colors[7] = colors_base[8]
map_colors[8] = colors_base[9]
map_colors[9] = colors_base[10]
map_colors[10] = colors_base[11]
map_colors[11] = colors_base[12]
map_colors[12] = colors_base[13]
map_colors[13] = colors_base[14]
map_colors[14] = colors_base[15]
map_colors[15] = colors_base[16]
map_colors[16] = colors_base[17]
map_colors[17] = colors_base[18]
map_colors[18] = colors_base[19]
map_colors[19] = colors_base[20]
map_colors[20] = colors_base[21]
map_colors[21] = colors_base[22]
map_colors[22] = colors_base[23]
map_colors[23] = colors_base[24]
map_colors[24] = colors_base[25]
map_colors[25] = colors_base[26]
map_colors[26] = colors_base[27]
map_colors[27] = colors_base[28]
map_colors[28] = colors_base[29]
map_colors[29] = colors_base[30]
map_colors[30] = colors_base[31]
map_colors[31] = colors_base[1]
map_colors[32] = colors_base[32]
map_colors[33] = '#616161'

# Make and save the map
map = ggplot() +
  geom_polygon(data=map_counties, aes(x = long, y = lat, 
                                      group = group, fill = county_type),
               color = '#616161', size = .1) +
  geom_polygon(data=map_states, aes(x = long, y = lat, group=group),
               fill=NA, color = '#444444', size = .3) + 
  coord_map("albers", lat0=40, lat1=45) +
  theme_void() + 
  guides(fill = guide_legend(title = '', title.position = 'top')) +
  scale_fill_manual(values = map_colors) +
  theme(legend.position = 'bottom',
        legend.title = element_text(color = 'black', size = 20),
        legend.text = element_text(size = 20),
        legend.key.size = unit(1, 'cm'))
ggsave("../output/figures/Figure_2.pdf", map, width=10, height=10)


# Figure 3: Growth in Appointed Election Officials Across 13 States, 1960-2022
datgraph_overall_tab <- dat %>% 
  group_by(year) %>% 
  mutate(prop_appointed = sum(appointed, na.rm = TRUE)/n(),
         prop_elected = 1 - prop_appointed) %>% 
  select(year, prop_elected, prop_appointed) %>% 
  slice(1)
datgraph_overall <- datgraph_overall_tab %>% 
  ggplot(aes(x = year, y = prop_appointed)) +
  geom_point() + geom_line() +
  labs(y = "Percent of Counties with Appointed Election Officials",
       x = "Year") +
  ylim(0, 1) +
  xlim(1960, 2022) +
  expand_limits(y = 0) +
  theme_bw() +
  theme(legend.position= "bottom") +
  scale_x_continuous(breaks = seq(1960, 2022, by = 10)) +
  scale_y_continuous(labels = scales::percent, limits = c(0,0.5))
ggsave("../output/figures/Figure_3.pdf", device = pdf)

## "The percentage of counties that appoint their election officials has grown from 2% in 1960 to 33% in 2022"
datgraph_overall_tab$prop_appointed[datgraph_overall_tab$year == 1960]
datgraph_overall_tab$prop_appointed[datgraph_overall_tab$year == 2022]

# Figure 4: Estimated ATT of Generalized Synthetic Control
set.seed(1234)

gsynth_dat <- dat %>% 
  drop_na(turnout_pc, appointed)

out <- gsynth(turnout_pc ~ appointed,
              data = gsynth_dat,
              index = c("fips", "year"),
              force = "two-way",
              CV = TRUE,
              min.T0 = 7,
              se = TRUE,
              inference = "parametric",
              parallel = TRUE,
              nboots = 1000)

gsynth_dat <- data.table(att = out$est.att[,1],
                         se = out$est.att[,2],
                         ci.l = out$est.att[,3],
                         ci.u = out$est.att[,4],
                         time = seq(-6, 21, by = 1),
                         treat_avg = out$Y.tr.cnt,
                         control_avg = out$Y.ct.cnt)

new_gsynch <- ggplot(dat = gsynth_dat, aes(x = time, y = att)) +
  geom_ribbon(aes(x = time, ymin = ci.l, ymax = ci.u), fill = "grey90", alpha = .8, linetype = 2) +
  geom_point(size = 2) + geom_line(linewidth = 1.25) +
  scale_x_continuous(limits = c(-6, 8), breaks = seq(-6, 8, 2), minor_breaks = seq(-6, 8, 1)) +
  scale_y_continuous(limits = c(-.02, .04), breaks = seq(-.02, .04, .01)) +
  geom_vline(xintercept = 0) +
  geom_hline(yintercept = 0) +
  theme_bw() +
  xlab("Even-Year General Elections Since Switch to Appointed Official") +
  ylab("Effect on Voter Turnout") +
  theme(panel.grid.major.x =  element_line(size = ifelse(seq(-6,8, 1) %% 1 == 0, 1, 0)))
ggsave("../output/figures/Figure_4.pdf", device = pdf, height = 5)


# Figure 5: Randomization Inference for Table 1, Columns 1-3 - Timing of Treated Counties
set.seed(123)

dat_rand <- dat %>% 
  filter(appoint_to_elect!=1 & multiple_switches != 1) %>% 
  mutate(cohort = as.numeric(cohort)) 

rand_fun2 <- function(data, samples) {
  coeffs <- data.frame(matrix(ncol = 3, nrow = samples))
  for (i in 1:samples) {
    newdat <- dat_rand %>% 
      group_by(state, fips) %>%
      slice(1) %>% 
      group_by(state) %>% 
      mutate(cohort_shuffled = ifelse(cohort == 0, 0, sample(cohort, replace = FALSE))) %>% 
      ungroup() %>% 
      select(fips, cohort_shuffled) %>% 
      full_join(dat_rand, by = "fips") %>% 
      mutate(appointed = case_when(
        cohort_shuffled == 0 ~ 0,
        cohort_shuffled <= year ~ 1,
        TRUE ~ 0))
    coeffs[i,1] <- as.numeric(coef(feols(turnout_pc ~ appointed  | year_state + fips, cluster = "fips", data=newdat)))
    coeffs[i,2] <- as.numeric(coef(feols(turnout_pc ~ appointed  | year_state_demvs + fips, cluster = "fips", data=newdat)))
    coeffs[i,3] <- as.numeric(coef(feols(turnout_pc ~ appointed  | year_state_pop + fips, cluster = "fips", data=newdat)))}
  return(coeffs)
}

test2_a <- rand_fun2(data = dat_rand, samples = 1000) %>% 
  as_tibble()

test2 <- test2_a %>%  
  pivot_longer(
    cols = everything(),
    names_to = "reg",
    values_to =  "coef")

sim_dat2 <- test2 %>% 
  mutate(true_coef = case_when(
    reg == "X1" ~ as.numeric(coef(feols(turnout_pc ~ appointed  | year_state + fips, cluster = "fips", data=dat_rand))),
    reg == "X2" ~ as.numeric(coef(feols(turnout_pc ~ appointed  | year_state_demvs + fips, cluster = "fips", data=dat_rand))),
    reg == "X3" ~ as.numeric(coef(feols(turnout_pc ~ appointed  | year_state_pop + fips, cluster = "fips", data=dat_rand)))),
    reg = case_when(
      reg == "X1" ~ "YearxState + County FE",
      reg == "X2" ~ "YearxStatexDemVS + County FE",
      reg == "X3" ~ "YearxStatexPop + County FE"))

sim_dat2 %>%  group_by(reg) %>% summarise(mean = mean(coef))

p_value_1 <- mean(test2_a$X1 >  as.numeric(coef(feols(turnout_pc ~ appointed  | year_state + fips, cluster = "fips", data=dat_rand))))
p_value_2 <- mean(test2_a$X2 >  as.numeric(coef(feols(turnout_pc ~ appointed  | year_state_demvs + fips, cluster = "fips", data=dat_rand))))
p_value_3 <- mean(test2_a$X3 >  as.numeric(coef(feols(turnout_pc ~ appointed  | year_state_pop + fips, cluster = "fips", data=dat_rand))))

sim_dat2 <- sim_dat2 %>% 
  mutate(p_value = case_when(
    reg == "YearxState + County FE" ~ p_value_1,
    reg == "YearxStatexDemVS + County FE" ~ p_value_2,
    reg == "YearxStatexPop + County FE" ~ p_value_3))

ggplot(data = sim_dat2, aes(x = coef)) +
  geom_density() +
  geom_vline(aes(xintercept = true_coef), color = "red", linetype = "solid") +
  geom_text(aes(x = Inf, y = Inf, label = paste("P-value =", round(p_value, 3))),
            hjust = 1.1, vjust = 1.1) +
  theme_bw() +
  facet_wrap(~reg) +
  xlab("Coefficient of Effect of Appointment on Turnout") +
  ylab("Density")
ggsave("../output/figures/Figure_5.pdf", device = pdf, height = 8, width = 8)


# Figure A.1: Local Election Official Selection Method by County
map_counties <- read.csv("../raw_data/dat_extended.csv") %>% 
  filter(year == 2022) %>% 
  mutate(state = abbr2state(state)) %>% 
  rename(region = state,
         subregion=county) %>% 
  mutate(region = str_to_lower(region),
         subregion = str_to_lower(subregion),
         subregion = case_when(
           subregion=="dekalb" & region=="alabama" ~ "de kalb",
           subregion == "dekalb" & region == "georgia" ~ "de kalb",
           subregion=="dekalb" & region=="illinois" ~ "de kalb",
           subregion=="dewitt" & region=="illinois" ~ "de witt",
           subregion=="dupage" & region=="illinois" ~ "du page",
           subregion=="lasalle" & region=="illinois" ~ "la salle",
           subregion == "st. clair" & region == "illinois" ~ "st clair",
           subregion == "dekalb" & region == "indiana" ~ "de kalb",
           subregion == "st. joseph" & region == "indiana" ~ "	st joseph",
           subregion == "st. louis" & region == "minnesota" ~ "st louis",
           subregion=="dekalb" & region=="missouri" ~ "de kalb",
           subregion == "st. charles" & region == "missouri" ~ "st charles",
           subregion == "st. clair" & region == "missouri" ~ "st clair",
           subregion == "ste. genevieve" & region == "missouri" ~ "ste genevieve",
           subregion == "st. francois" & region == "missouri" ~ "st francois",
           subregion =="st. louis" & region == "missouri" ~ "st louis",
           subregion == "st. louis city" & region == "missouri" ~ "st louis city",
           subregion =="dewitt" & region =="texas" ~ "de witt",
           subregion =="desoto" & region =="florida" ~ "de soto",
           subregion == "laporte" & region == "iowa" ~ "la porte",
           subregion == "o'brien" & region == "iowa" ~ "obrien",
           subregion == "prince george's" ~ "prince georges",
           subregion == "queen anne's" ~ "queen annes",
           subregion == "st mary's" ~ "st marys",
           subregion == "desoto" & region == "mississippi" ~ "de soto",
           subregion == "lamoure" & region == "north dakota" ~ "la moure",
           subregion == "dekalb" & region == "tennessee" ~ "de kalb",
           TRUE ~ subregion)) %>% 
  select(region, subregion, appointed) %>% 
  full_join(map_data('county'), by = c("region", "subregion"))

map_states = map_data('state')

colors_base = brewer.pal(4, 'Blues')
map_colors = colors_base
map_colors[1] = colors_base[2]
map_colors[2] = colors_base[3]
map_colors[3] = colors_base[4]
map_colors[4] = '#616161' ## for municipal / exclude

map_selection = 
  ggplot() +
  geom_polygon(data=map_counties %>% 
                 mutate(
                   selection_label = case_when(
                     region == "indiana" & subregion %in% c("lake", "porter", "tippecanoe") ~'Mixed',
                     region %in% c("wisconsin", "michigan", "maine", "vermont", "new hampshire",
                                   "massachusetts", "rhode island", "connecticut") ~ "Municipal Authority",
                     appointed==1 | region == "virginia" ~ 'Appointed',
                     appointed==0 | region == "south dakota" ~ 'Elected',
                     region %in% c("missouri", "maryland", "district of columbia", "new york") | subregion == "broomfield" ~ "Appointed",
                     region %in% c("illinois", "indiana") | subregion == "yellowstone national" ~ "Elected"),
                   selection_label = factor(selection_label, levels = c("Appointed", "Mixed", "Elected", "Municipal Authority"))) %>% 
                 filter(!is.na(lat)),
               aes(x = long, y = lat, group = group, fill = selection_label),
               color = '#616161', size = .1) +
  geom_polygon(data=map_states, aes(x = long, y = lat, group=group),
               fill=NA, 
               # color = '#444444', 
               color = 'black',
               size = 1) + 
  coord_map("albers", lat0=39, lat1=45) +
  theme_void() + 
  guides(fill = guide_legend(title = '', title.position = 'top')) +
  scale_fill_manual(values = map_colors) +
  theme(legend.position = 'bottom',
        legend.title = element_text(color = 'black', size = 18),
        legend.text = element_text(size = 25),
        legend.key.size = unit(0.75, 'cm'))
ggsave("../output/figures/Figure_A.1.pdf", map_selection, width=15, height=9)


# Figure A.2: Average Effect of Appointed Election Officials on Voter Turnout by Length of Exposure to Appointing
set.seed(1234)

dat_call <- dat %>% 
  filter(always_appointed == 0 & multiple_switches != 1 & appoint_to_elect != 1 & ever_divided != 1)

Callaway_2 <- att_gt(yname = "turnout_pc",
                     tname = "year",
                     idname = "fips",
                     gname = "cohort",
                     data = dat_call,
                     xformla = ~ state,
                     allow_unbalanced_panel = FALSE,
                     control_group = "nevertreated",
                     bstrap = TRUE,
                     cband = TRUE,
                     biters = 1000,
                     clustervars = "fips",
                     est_method = "dr",
                     base_period = "varying")

Callaway_dynamic_2 <- aggte(Callaway_2, type = "dynamic", na.rm = TRUE)
summary(Callaway_dynamic_2)
ggdid(Callaway_dynamic_2,
      xlab = "Years of Exposure to Appointing Election Official",
      ylab = "Effect on Voter Turnout",
      title = " ",
      xgap = 2)
ggsave("../output/figures/Figure_A.2.pdf", device = pdf)


# Figure A.3: Average Effect of Appointed Election Officials on Voter Turnout by Cohort Group
## Run lines 373--391 above first

Callaway_groups_2 <- aggte(Callaway_2, type = "group", na.rm = TRUE)
summary(Callaway_groups_2)
ggdid(Callaway_groups_2,
      ylab = "Year of Switch to Appointed Election Official",
      xlab = "Effect on Voter Turnout",
      title = " ")
ggsave("../output/figures/Figure_A.3.pdf", device = pdf, height = 8)


# Figure A.4: Average Effect of Appointed Election Officials on Voter Turnout by Time Period
## Run lines 373--391 above first

Callaway_time_2 <- aggte(Callaway_2, type = "calendar", na.rm = TRUE)
summary(Callaway_time_2)
ggdid(Callaway_time_2,
      ylab = "Average Effect on Voter Turnout",
      xlab = "Time Period",
      title = " ",
      xgap = 2)
ggsave("../output/figures/Figure_A.4.pdf", device = pdf)


# Figure A.5: Dube et al. (2022) Local Projections Difference-in-Differences Estimate of Effect of Appointing an Election Official on Voter Turnout
## d = data; k = number of lags and leads; y = outcome; t = period (year); i = individual/county index; g = cohort; w_g = ever treated

lag_lead = function(x, k){
  if(k<0){
    lag = lead(x, -k-1)
  }
  else {
    lag = lag(x, k+1)
  }
  return(lag)
}

d = dat %>%
  group_by(fips) %>%
  filter(min(appointed)==0) %>%
  ungroup() %>%
  filter(appoint_to_elect==0) %>%
  select(state, fips, year, cohort, evertreated, appointed, turnout_pc, pop_quart) %>%
  mutate(cohort = ifelse(cohort==0, NA, cohort), 
         cohort = ceiling(cohort/2)) %>%
  mutate(t = year/2)

coefs = matrix(nrow = 33, ncol = 2)

for(k in -16:16) {
  r = k + 17 # whatever abs(negative) + 1 
  if(k==-1) {
    coefs[r, ] = c(0, 0)}
  else{
    d_k = d %>%
      group_by(fips) %>%
      arrange(fips, t) %>%
      mutate(lag_y = lag_lead(turnout_pc, k),
             y_lag_y = turnout_pc - lag_y) %>%
      filter(evertreated==0 | t-cohort==k) %>%
      filter(!is.na(y_lag_y))
    est = feols(y_lag_y ~ evertreated | t^as.factor(state)^as.factor(pop_quart), data=d_k, cluster="fips")
    coefs[r, ] = c(est$coefficients, est$se)}
}

coefs_dat <- as.data.frame(coefs) %>% 
  rename(estimate = V1,
         se = V2) %>% 
  mutate(conf.low = estimate - se*1.96,
         conf.high = estimate + se*1.96,
         term = seq(-16,16),
         before = ifelse(term < 0, 1, 0))

ggplot(coefs_dat, aes(term, estimate, color=factor(before)))+
  geom_point() +
  geom_pointrange(aes(ymin = conf.low, ymax = conf.high))+
  labs(x = "Even-Year General Elections Before and After Switch",
       y = "Effect of Switching to Appointment on Turnout") +
  theme_bw() +
  theme(legend.position = "None") +
  geom_hline(yintercept=0, linetype = "solid", color = "black") +
  geom_vline(xintercept=0, linetype = "dashed", color = "black") +
  scale_y_continuous(breaks= seq(-.04, .08, .02)) +
  scale_x_continuous(breaks = seq(-16,16,1)) +
  scale_color_manual(values = c("blue", "black")) 

ggsave("../output/figures/Figure_A.5.pdf", width = 10, device = pdf)


# Figure A.6: Dube et al. (2022) Local Projections Difference-in-Differences Estimate of Effect of Appointing an Election Official on Registration
lag_lead = function(x, k){
  if(k<0){
    lag = lead(x, -k-1)
  }
  else {
    lag = lag(x, k+1)
  }
  return(lag)
}

d = dat %>%
  group_by(fips) %>%
  filter(min(appointed)==0) %>%
  ungroup() %>%
  filter(appoint_to_elect==0) %>%
  select(state, fips, year, cohort, evertreated, appointed, reg_pc, pop_quart) %>%
  mutate(cohort = ifelse(cohort==0, NA, cohort), 
         cohort = ceiling(cohort/2)) %>%
  mutate(t = year/2)

coefs = matrix(nrow = 13, ncol = 2)

for(k in -6:6) {
  r = k + 7 # whatever abs(negative) + 1 
  if(k==-1) {
    coefs[r, ] = c(0, 0)}
  else{
    d_k = d %>%
      group_by(fips) %>%
      arrange(fips, t) %>%
      mutate(lag_y = lag_lead(reg_pc, k),
             y_lag_y = reg_pc - lag_y) %>%
      filter(evertreated==0 | t-cohort==k) %>%
      filter(!is.na(y_lag_y))
    est = feols(y_lag_y ~ evertreated | t^as.factor(state)^as.factor(pop_quart), data=d_k, cluster="fips")
    coefs[r, ] = c(est$coefficients, est$se)}
}

coefs_dat <- as.data.frame(coefs) %>% 
  rename(estimate = V1,
         se = V2) %>% 
  mutate(conf.low = estimate - se*1.96,
         conf.high = estimate + se*1.96,
         term = seq(-6,6),
         before = ifelse(term < 0, 1, 0))

ggplot(coefs_dat, aes(term, estimate, color=factor(before)))+
  geom_point() +
  geom_pointrange(aes(ymin = conf.low, ymax = conf.high))+
  labs(x = "Even-Year General Elections Before and After Switch",
       y = "Effect of Switching to Appointment on Registration") +
  theme_bw() +
  theme(legend.position = "None") +
  geom_hline(yintercept=0, linetype = "solid", color = "black") +
  geom_vline(xintercept=0, linetype = "dashed", color = "black") +
  scale_y_continuous(breaks= seq(-.04, .08, .02)) +
  scale_x_continuous(breaks = seq(-8,8,1)) +
  scale_color_manual(values = c("blue", "black")) 

ggsave("../output/figures/Figure_A.6.pdf", device = pdf)


# Figure A.7: Dube et al. (2022) Local Projections Difference-in-Differences Estimate of Effect of Appointing an Election Official on Turnover
dat_turnout <- dat %>% 
  mutate(turnover2_alt = ifelse(year == cohort & appointed == 1, NA, turnover2))

lag_lead = function(x, k){
  if(k<0){
    lag = lead(x, -k-1)
  }
  else {
    lag = lag(x, k+1)
  }
  return(lag)
}

d = dat_turnout %>%
  group_by(fips) %>%
  filter(min(appointed)==0) %>%
  ungroup() %>%
  filter(appoint_to_elect==0) %>%
  select(state, fips, year, cohort, evertreated, appointed, turnover2, pop_quart) %>%
  mutate(cohort = ifelse(cohort==0, NA, cohort), 
         cohort = ceiling(cohort/2)) %>%
  mutate(t = year/2)

coefs = matrix(nrow = 11, ncol = 2)

for(k in -5:5) {
  r = k + 6 # whatever abs(negative) + 1 
  if(k==-1) {
    coefs[r, ] = c(0, 0)}
  else{
    d_k = d %>%
      group_by(fips) %>%
      arrange(fips, t) %>%
      mutate(lag_y = lag_lead(turnover2, k),
             y_lag_y = turnover2 - lag_y) %>%
      filter(evertreated==0 | t-cohort==k) %>%
      filter(!is.na(y_lag_y))
    est = feols(y_lag_y ~ evertreated | t^as.factor(state)^as.factor(pop_quart), data=d_k, cluster="fips")
    coefs[r, ] = c(est$coefficients, est$se)}
}

coefs_dat <- as.data.frame(coefs) %>% 
  rename(estimate = V1,
         se = V2) %>% 
  mutate(conf.low = estimate - se*1.96,
         conf.high = estimate + se*1.96,
         term = seq(-5,5),
         before = ifelse(term < 0, 1, 0))

ggplot(coefs_dat, aes(term, estimate, color=factor(before)))+
  geom_point() +
  geom_pointrange(aes(ymin = conf.low, ymax = conf.high))+
  labs(x = "Even-Year General Elections Before and After Switch",
       y = "Effect of Switching to Appointment on Turnover") +
  theme_bw() +
  theme(legend.position = "None") +
  geom_hline(yintercept=0, linetype = "solid", color = "black") +
  geom_vline(xintercept=0, linetype = "dashed", color = "black") +
  scale_y_continuous(breaks= seq(0, 1, .1)) +
  scale_x_continuous(breaks = seq(-5,5,1)) +
  scale_color_manual(values = c("blue", "black")) 

ggsave("../output/figures/Figure_A.7.pdf", device = pdf)


# Figure A.8: Dube et al. (2022) Local Projections Difference-in-Differences Estimate of Effect of Appointing an Election Official on Logged Expenditures Per Registrant
lag_lead = function(x, k){
  if(k<0){
    lag = lead(x, -k-1)
  }
  else {
    lag = lag(x, k+1)
  }
  return(lag)
}

d = dat %>%
  group_by(fips) %>%
  filter(min(appointed)==0) %>%
  ungroup() %>%
  filter(appoint_to_elect==0) %>%
  select(state, fips, year, cohort, evertreated, appointed, log_expnd_per_reg, pop_quart) %>%
  mutate(cohort = ifelse(cohort==0, NA, cohort), 
         cohort = ceiling(cohort/2)) %>%
  mutate(t = year/2)

coefs = matrix(nrow = 9, ncol = 2)

for(k in -4:4) {
  r = k + 5 # whatever abs(negative) + 1 
  if(k==-1) {
    coefs[r, ] = c(0, 0)}
  else{
    d_k = d %>%
      group_by(fips) %>%
      arrange(fips, t) %>%
      mutate(lag_y = lag_lead(log_expnd_per_reg, k),
             y_lag_y = log_expnd_per_reg - lag_y) %>%
      filter(evertreated==0 | t-cohort==k) %>%
      filter(!is.na(y_lag_y))
    est = feols(y_lag_y ~ evertreated | t^as.factor(state)^as.factor(pop_quart), data=d_k, cluster="fips")
    coefs[r, ] = c(est$coefficients, est$se)}
}

coefs_dat <- as.data.frame(coefs) %>% 
  rename(estimate = V1,
         se = V2) %>% 
  mutate(conf.low = estimate - se*1.96,
         conf.high = estimate + se*1.96,
         term = seq(-4,4),
         before = ifelse(term < 0, 1, 0))

ggplot(coefs_dat, aes(term, estimate, color=factor(before)))+
  geom_point() +
  geom_pointrange(aes(ymin = conf.low, ymax = conf.high))+
  labs(x = "Even-Year General Elections Before and After Switch",
       y = "Effect of Switching to Appointment on Log(Expend Per Reg)") +
  theme_bw() +
  theme(legend.position = "None") +
  geom_hline(yintercept=0, linetype = "solid", color = "black") +
  geom_vline(xintercept=0, linetype = "dashed", color = "black") +
  scale_y_continuous(breaks= seq(-4, 5, .5)) +
  scale_x_continuous(breaks = seq(-4,4,1)) +
  scale_color_manual(values = c("blue", "black")) 

ggsave("../output/figures/Figure_A.8.pdf", device = pdf)


# Figure A.9: Randomization Inference for Table 1, Columns 1-3 - Treatment and Timing
set.seed(123)

dat_rand <- dat %>% 
  filter(appoint_to_elect!=1 & multiple_switches != 1) %>% 
  mutate(cohort = as.numeric(cohort)) 

rand_fun <- function(data, samples) {
  coeffs <- data.frame(matrix(ncol = 3, nrow = samples))
  for (i in 1:samples) {
    newdat <- dat_rand %>% 
      group_by(state, fips) %>%
      slice(1) %>% 
      group_by(state) %>% 
      mutate(cohort_shuffled = sample(cohort, replace = FALSE)) %>% 
      ungroup() %>% 
      select(fips, cohort_shuffled) %>% 
      full_join(dat_rand, by = "fips") %>% 
      mutate(appointed = case_when(
        cohort_shuffled == 0 ~ 0,
        cohort_shuffled <= year ~ 1,
        TRUE ~ 0))
    coeffs[i,1] <- as.numeric(coef(feols(turnout_pc ~ appointed  | year_state + fips, cluster = "fips", data=newdat)))
    coeffs[i,2] <- as.numeric(coef(feols(turnout_pc ~ appointed  | year_state_demvs + fips, cluster = "fips", data=newdat)))
    coeffs[i,3] <- as.numeric(coef(feols(turnout_pc ~ appointed  | year_state_pop + fips, cluster = "fips", data=newdat)))}
  return(coeffs)
}

test_a <- rand_fun(data = dat_rand, samples = 1000) %>% 
  as_tibble()

test <- test_a %>%  
  pivot_longer(
    cols = everything(),
    names_to = "reg",
    values_to =  "coef")

sim_dat <- test %>% 
  mutate(true_coef = case_when(
    reg == "X1" ~ as.numeric(coef(feols(turnout_pc ~ appointed  | year_state + fips, cluster = "fips", data=dat_rand))),
    reg == "X2" ~ as.numeric(coef(feols(turnout_pc ~ appointed  | year_state_demvs + fips, cluster = "fips", data=dat_rand))),
    reg == "X3" ~ as.numeric(coef(feols(turnout_pc ~ appointed  | year_state_pop + fips, cluster = "fips", data=dat_rand)))),
    reg = case_when(
      reg == "X1" ~ "YearxState + County FE",
      reg == "X2" ~ "YearxStatexDemVS + County FE",
      reg == "X3" ~ "YearxStatexPop + County FE"))

p_1 <- mean(test_a$X1 >  as.numeric(coef(feols(turnout_pc ~ appointed  | year_state + fips, cluster = "fips", data=dat_rand))))
p_2 <- mean(test_a$X2 >  as.numeric(coef(feols(turnout_pc ~ appointed  | year_state_demvs + fips, cluster = "fips", data=dat_rand))))
p_3 <- mean(test_a$X3 >  as.numeric(coef(feols(turnout_pc ~ appointed  | year_state_pop + fips, cluster = "fips", data=dat_rand))))

sim_dat <- sim_dat %>% 
  mutate(p_value = case_when(
    reg == "YearxState + County FE" ~ p_1,
    reg == "YearxStatexDemVS + County FE" ~ p_2,
    reg == "YearxStatexPop + County FE" ~ p_3))

ggplot(data = sim_dat, aes(x = coef)) +
  geom_density() +
  geom_vline(aes(xintercept = true_coef), color = "red", linetype = "solid") +
  geom_text(aes(x = Inf, y = Inf, label = paste("P-value =", round(p_value, 3))),
            hjust = 1.1, vjust = 1.1) +
  theme_bw() +
  facet_wrap(~reg) +
  xlab("Coefficient of Effect of Appointment on Turnout") +
  ylab("Density")
ggsave("../output/figures/Figure_A.9.pdf", device = pdf, height = 10, width = 10)