# Electing Local Election Officials Replication Code: Data Analysis - Tables
library(tidyverse); library(fixest); library(haven); library(DIDmultiplegt)
library(kableExtra); library(PanelMatch); library(did); library(gsynth); library(survey)

dat <- read.csv("../dat.csv")
path <- getwd()

# Table 1: Appointing Local Election Officials Increases Citizen Participation (Even-Year General Elections, 1968-2022) 
reg1f <- feols(turnout_pc ~ appointed | year_state + fips, cluster = "fips", data=dat)
reg1af <- feols(turnout_pc ~ appointed | year_state_demvs + fips, cluster = "fips", data=dat)
reg1bf <- feols(turnout_pc ~ appointed | year_state_pop + fips, cluster = "fips", data=dat)
reg7wof <- feols(reg_pc ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, reg_separate == 0))
reg7woaf <- feols(reg_pc ~ appointed | year_state_demvs + fips, cluster = "fips", data=filter(dat, reg_separate == 0))
reg7wobf <- feols(reg_pc ~ appointed | year_state_pop + fips, cluster = "fips", data=filter(dat, reg_separate == 0))

cat(
  "\\begin{table}[h!]",
  "\\centering", 
  "\\caption{\\textbf{Appointing Local Election Officials Increases Citizen Participation (Even-Year General Elections, 1968-2022)}",
  "\\label{tab:citizen_participation_full}}",
  "\\begin{tabular}{lcccccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{3}{c}{Voter Turnout} & \\multicolumn{3}{c}{Registration Rate}\\\\",
  " & (1) & (2) & (3) & (4) & (5) & (6) \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", reg1f$coefficients[1], reg1af$coefficients[1], reg1bf$coefficients[1], reg7wof$coefficients[1], reg7woaf$coefficients[1], reg7wobf$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", reg1f$se[1], reg1af$se[1], reg1bf$se[1], reg7wof$se[1], reg7woaf$se[1], reg7wobf$se[1]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", fitstat(reg1f,"G"), fitstat(reg1af,"G"), fitstat(reg1bf,"G"), fitstat(reg7wof,"G"), fitstat(reg7woaf,"G"), fitstat(reg7wobf,"G")),
  sprintf("Elections & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", reg1f$fixef_sizes[1]/13, reg1af$fixef_sizes[1]/52, reg1bf$fixef_sizes[1]/52, reg7wof$fixef_sizes[1]/11, reg7woaf$fixef_sizes[1]/44, reg7wobf$fixef_sizes[1]/44),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", reg1f$nobs, reg1af$nobs, reg1bf$nobs, reg7wof$nobs, reg7woaf$nobs, reg7wobf$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f \\\\", fitstat(reg1f,"my"), fitstat(reg1af,"my"), fitstat(reg1bf,"my"), fitstat(reg7wof,"my"), fitstat(reg7woaf,"my"), fitstat(reg7wobf,"my")),
  "County FEs & Yes & Yes & Yes & Yes & Yes & Yes \\\\",
  "Year x State FEs & Yes & No & No & Yes & No & No  \\\\",
  "Year x State x Dem vs FEs & No & Yes & No & No & Yes & No \\\\",
  "Year x State x Pop FEs & No & No & Yes & No & No & Yes \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{7}{p{.925\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses. Voter turnout and registration rate are measured as proportions out of 1. The number of observations is smaller in columns 4-6 because Arizona and Georgia are excluded and because turnout data is available from 1968 but registration data is only available from 1996.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_1.tex"), sep="\n")


# Table 2: Appointing Local Election Officials Increases Election Expenditures (Even-Year General Elections, 2004-2016)
regcostreg <- feols(log_expnd_per_reg ~ appointed | year_state + fips, cluster = "fips", data=dat)
regcostrega <- feols(log_expnd_per_reg ~ appointed | year_state_demvs + fips, cluster = "fips", data=dat)
regcostregb <- feols(log_expnd_per_reg ~ appointed | year_state_pop + fips, cluster = "fips", data=dat)
regcostregx <- feols(log_expnd_per_reg ~ appointed + appointedXsmall | year_state_small + fips_small, cluster = "fips_small", data=dat)
regcostregax <- feols(log_expnd_per_reg ~ appointed  + appointedXsmall| year_state_demvs_small + fips_small, cluster = "fips_small", data=dat)
regcostregbx <- feols(log_expnd_per_reg ~ appointed + appointedXsmall | year_state_pop + fips_small, cluster = "fips_small", data=dat)

cat(
  "\\begin{table}[h!]",
  "\\centering", 
  "\\caption{\\textbf{Appointing Local Election Officials Increases Election Expenditures (Even-Year General Elections, 2004-2016)}",
  "\\label{tab:election_costs_size}}",
  "\\begin{tabular}{lcccccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{6}{c}{Ln(Total Election Expenditures Per Registered Voter)} \\\\",
  " & (1) & (2) & (3) & (4) & (5) & (6) \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", regcostreg$coefficients[1], regcostrega$coefficients[1], regcostregb$coefficients[1], regcostregx$coefficients[1], regcostregax$coefficients[1], regcostregbx$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regcostreg$se[1], regcostrega$se[1], regcostregb$se[1], regcostregx$se[1], regcostregax$se[1], regcostregbx$se[1]),
  sprintf("Appointed X Small County &  &  &  & %1.3f & %1.3f & %1.3f  \\\\", regcostregx$coefficients[2], regcostregax$coefficients[2], regcostregbx$coefficients[2]),
  sprintf(" &  &  &  & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regcostregx$se[2], regcostregax$se[2], regcostregbx$se[2]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", fitstat(regcostreg,"G"), fitstat(regcostrega,"G"), fitstat(regcostregb,"G"), fitstat(regcostregx,"G"), fitstat(regcostregax,"G"), fitstat(regcostregbx,"G")),
  sprintf("Elections & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", floor(regcostreg$fixef_sizes[1]/7), floor(regcostrega$fixef_sizes[1]/28), floor(regcostregb$fixef_sizes[1]/28), floor(regcostregx$fixef_sizes[1]/14), regcostregax$fixef_sizes[1]/56, floor(regcostregbx$fixef_sizes[1]/28)),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", regcostreg$nobs, regcostrega$nobs, regcostregb$nobs, regcostregx$nobs, regcostregax$nobs, regcostregbx$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f \\\\", fitstat(regcostreg,"my"), fitstat(regcostrega,"my"), fitstat(regcostregb,"my"), fitstat(regcostregx,"my"), fitstat(regcostregax,"my"), fitstat(regcostregbx,"my")),
  "County FEs & Yes & Yes & Yes & Yes & Yes & Yes \\\\",
  "Year x State FEs & Yes & No & No & No & No & No  \\\\",
  "Year x State x Dem vs FEs & No & Yes & No & No & No & No  \\\\",
  "Year x State x Pop FEs & No & No & Yes & No & No & Yes  \\\\",
  "Year x State x Small FEs & No & No & No & Yes & No & No  \\\\",
  "Year x State x Dem vs x Small FEs & No & No & No & No & Yes & No \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{7}{p{1\\textwidth}}{\\footnotesize Small counties rank in the bottom half in population compared to other counties within the same state. Robust standard errors clustered by county in parentheses. Data is from Mohr et al. (2018) and is available for Arizona, California, Georgia, Minnesota, Missouri, Nebraska, and Nevada. Elections are the average number of elections included for each state, rounded down to the nearest interger. Expenditure data is normalized to 2020 dollars.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_2.tex"), sep="\n")

## "The average county spends $9.50 per registered voter on administering elections in even years, 
## and appointed officials secure an additional $3.06 per registrant."
exp(as.numeric(fitstat(regcostreg,"my")))
(exp(regcostreg$coefficients[1])-1)*exp(as.numeric(fitstat(regcostreg,"my")))

# Table 3: Appointed Local Election Officials May Decrease Voter Wait Times (Even-Year General Elections, 2008-2022)
problems_dat <- read.csv("../raw_data/spae_cleaned.csv") %>% 
  inner_join(dat, by = c("fips", "year"))

regwaitia <- feols(wait_min ~ appointed +  gender + as.factor(race) + birthyr + as.factor(educ) + as.factor(pid7)  | year_state + fips, cluster = "fips", weights = problems_dat$weight, data = problems_dat)
regwaitib <- feols(wait_over_10 ~ appointed +  gender + as.factor(race) + birthyr + as.factor(educ) + as.factor(pid7)  | year_state + fips, cluster = "fips", weights = problems_dat$weight, data = problems_dat)
regwaitic <- feols(wait_over_30 ~ appointed +  gender + as.factor(race) + birthyr + as.factor(educ) + as.factor(pid7)  | year_state + fips, cluster = "fips", weights = problems_dat$weight, data = problems_dat)
regwaitid <- feols(wait_over_1hr ~ appointed +  gender + as.factor(race) + birthyr + as.factor(educ) + as.factor(pid7)  | year_state + fips, cluster = "fips", weights = problems_dat$weight, data = problems_dat)

cat(
  "\\begin{table}[h!]",
  "\\centering", 
  "\\caption{\\textbf{Appointed Local Election Officials May Decrease Voter Wait Times (Even-Year General Elections, 2008-2022)}",
  "\\label{tab:wait_times}}",
  "\\begin{tabular}{lcccc}",
  "\\toprule \\toprule",
  " & Min Waited & $>$ 10 min & $>$ 30 min & $>$ 1 hr \\\\",
  " & (1) & (2) & (3) & (4) \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", regwaitia$coefficients[1], regwaitib$coefficients[1], regwaitic$coefficients[1], regwaitid$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f)  \\\\[2mm]", regwaitia$se[1], regwaitib$se[1], regwaitic$se[1], regwaitid$se[1]),
  sprintf("Counties & %4.0f & %4.0f & %4.0f  & %4.0f\\\\", fitstat(regwaitia,"G"), fitstat(regwaitib,"G"), fitstat(regwaitic,"G"), fitstat(regwaitid,"G")),
  sprintf("Respondents & %4.0f & %4.0f & %4.0f  & %4.0f\\\\", fitstat(regwaitia,"n"), fitstat(regwaitib,"n"), fitstat(regwaitic,"n"), fitstat(regwaitid,"n")),
  sprintf("Elections & %4.0f & %4.0f & %4.0f & %4.0f \\\\", regwaitia$fixef_sizes[1]/13, regwaitib$fixef_sizes[1]/13, regwaitic$fixef_sizes[1]/13, regwaitid$fixef_sizes[1]/13),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f \\\\", regwaitia$nobs, regwaitib$nobs, regwaitic$nobs, regwaitid$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f \\\\", fitstat(regwaitia,"my"), fitstat(regwaitib,"my"), fitstat(regwaitic,"my"), fitstat(regwaitid,"my")),
  "County FEs & Yes & Yes & Yes & Yes  \\\\",
  "Year x State FEs & Yes & Yes & Yes & Yes \\\\",
  "Individual Controls & Yes & Yes & Yes & Yes \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{5}{p{.7\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses. Individual controls are gender, race, age, education, and party identification.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_3.tex"), sep="\n")


# Table 4: Appointed Local Election Officials Possess More Education Than Elected Officials
## Clean EVIC LEO survey data
reed_dat <- read.csv("../raw_data/evic_leo_2020.csv")
reed_dat <- reed_dat %>% 
  mutate(size_ord = case_when(
    size == "> 250,000" ~ 5,
    size == "100,001 to 250,000" ~ 4,
    size == "25,001 to 100,000" ~ 3,
    size == "5,001 to 25,000" ~ 2,
    size == "0 to 5,000" ~ 1),
    appointed = ifelse(SELECTTYPE == "Appointed", 1, 0),
    experience = case_when(
      CURPOS_LEN == "20 years or more" ~ "20",
      CURPOS_LEN =="Less than one year" ~ "0",
      TRUE ~ CURPOS_LEN),
    experience = as.numeric(experience),
    education = case_when(
      Education == "High school" ~ 1,
      Education == "Some college" ~ 2,
      Education == "College" ~ 3,
      Education == "Some graduate school" ~ 4,
      Education == "Graduate school" ~ 5,
      TRUE ~ NA),
    edu_bin = ifelse(education >=3, 1, 0),
    any_college_bin = ifelse(education >= 2, 1, 0),
    admin_exp_yrs = ifelse(FIRSTYEAR=="Before 1970", 50, 2020 - as.numeric(FIRSTYEAR)),
    Membership_1 = ifelse(is.na(Membership_1), 0, 1),
    Membership_2 = ifelse(is.na(Membership_2), 0, 1),
    Membership_3 = ifelse(is.na(Membership_3), 0, 1),
    Membership_4 = ifelse(is.na(Membership_4), 0, 1),
    memberships = Membership_1 + Membership_2 + Membership_3 + Membership_4,
    other_leo = ifelse(OTHERLEO=="Yes", 1, 0),
    FTE_alt = case_when(
      FTE == "No full-time staff, including myself" ~ 1,
      FTE == "1" ~ 2,
      FTE == "2-5" ~ 3,
      FTE == "6-10" ~ 4,
      FTE == "11-20" ~ 5,
      FTE == "21-50" ~ 6,
      FTE == "More than 50" ~ 7,
      TRUE ~ NA),
    FTE = case_when(
      FTE == "No full-time staff, including myself" ~ 0.5,
      FTE == "1" ~ 1,
      FTE == "2-5" ~ 3.5,
      FTE == "6-10" ~ 8,
      FTE == "11-20" ~ 15.5,
      FTE == "21-50" ~ 35.5,
      FTE == "More than 50" ~ 50,
      TRUE ~ NA),
    small = case_when(
      total_pop < median(reed_dat$total_pop, na.rm = T) ~ 1,
      total_pop >= median(reed_dat$total_pop, na.rm = T) ~ 0,
      TRUE ~ NA),
    appointedXsmall = appointed*small,
    state_small = paste0(state, small),
    age = case_when(
      Age == "18-25" ~ 21.5,
      Age == "26-34" ~ 30,
      Age == "35-49" ~ 42,
      Age == "50-64" ~ 57,
      Age == "65+" ~ 65,
      TRUE ~ NA),
    over_65 = ifelse(age == 65, 1, 0),
    under_35 = ifelse(age == 30, 1, 0),
    salary = case_when(
      Salary == "Less than $20,000" ~ 20,
      Salary == "$20,000 to $34,999" ~ 27.5,
      Salary == "$35,000 to $49,999" ~ 42.5,
      Salary == "$50,000 to $74,999" ~ 62.5,
      Salary == "$75,000 +" ~ 75,
      TRUE ~ NA),
    membership_bin = ifelse(memberships == 0, 0, 1),
    prior_experience = admin_exp_yrs - experience,
    prior_experience = ifelse(prior_experience < 0, NA, prior_experience)) %>%
  filter(SCREENING == "Yes, I am the chief local election official")

## Run regressions
regmod2 <- feols(as.numeric(education) ~ appointed  + log_pop + log_pop_squared | state, cluster = "state", data=reed_dat, weights = reed_dat$weight) 
regmod2_a <- feols(as.numeric(edu_bin) ~ appointed  + log_pop + log_pop_squared | state, cluster = "state", data=reed_dat, weights = reed_dat$weight) 
regmod2_b <- feols(as.numeric(any_college_bin) ~ appointed  + log_pop + log_pop_squared | state, cluster = "state", data=reed_dat, weights = reed_dat$weight) 
regmodbina <- feols(as.numeric(education) ~ appointed + appointedXsmall + log_pop + log_pop_squared | state_small, cluster = "state_small", data=reed_dat, weights = reed_dat$weight)
regmodbinb <- feols(as.numeric(edu_bin) ~ appointed + appointedXsmall  + log_pop + log_pop_squared | state_small, cluster = "state_small", data=reed_dat, weights = reed_dat$weight) 
regmodbinc <- feols(as.numeric(any_college_bin) ~ appointed + appointedXsmall  + log_pop + log_pop_squared | state_small, cluster = "state_small", data=reed_dat, weights = reed_dat$weight) 

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Appointed Local Election Officials Possess More Education Than Elected Officials}",
  "\\label{tab:reed_dat_edu}}",
  "\\begin{tabular}{lcccccc}",
  "\\toprule \\toprule",
  " & Edu &  Degree & Any College &  Edu & Degree & Any College \\\\",
  " & (1) & (2) & (3) & (4) & (5) & (6) \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f   \\\\", regmod2$coefficients[1], regmod2_a$coefficients[1], regmod2_b$coefficients[1], regmodbina$coefficients[1], regmodbinb$coefficients[1], regmodbinc$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regmod2$se[1], regmod2_a$se[1], regmod2_b$se[1], regmodbina$se[1], regmodbinb$se[1], regmodbinc$se[1]),
  sprintf("Appointed X Small County &  &  &  & %1.3f & %1.3f & %1.3f   \\\\",  regmodbina$coefficients[2], regmodbinb$coefficients[2], regmodbinc$coefficients[2]),
  sprintf(" & &  & & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regmodbina$se[2], regmodbinb$se[2], regmodbinc$se[2]),
  "\\midrule",
  sprintf("States & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  & %4.0f  \\\\",  regmod2$fixef_sizes[1], regmod2_a$fixef_sizes[1], regmod2_b$fixef_sizes[1], regmodbina$fixef_sizes[1]/2, regmodbinb$fixef_sizes[1]/2,  regmodbinc$fixef_sizes[1]/2),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", regmod2$nobs, regmod2_a$nobs, regmod2_b$nobs, regmodbina$nobs, regmodbinb$nobs, regmodbinc$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f  & %1.2f  \\\\", fitstat(regmod2,"my"), fitstat(regmod2_a,"my"), fitstat(regmod2_b,"my"), fitstat(regmodbina,"my"), fitstat(regmodbinb,"my"), fitstat(regmodbinc,"my")),
  "State FEs & Yes & Yes & Yes & Yes & Yes  & Yes  \\\\",
  "Log Pop & Yes & Yes & Yes & Yes & Yes  & Yes  \\\\",
  "Log Pop squared & Yes & Yes & Yes & Yes & Yes  & Yes \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{7}{p{1\\textwidth}}{\\footnotesize Robust standard errors clustered by state in parentheses. Data is from the 2020 EVIC Survey of Local Election Officials and is filtered to only include chief local election officials. County is imputed from zip code to calculate population controls. Observations are weighted to be representative of the population of local election officials. Columns 1 and 4 measure educational attainment on a 5-point scale: high school, some college, college, some graduate school, and graduate school. Columns 2 and 5 measure whether the official possess a college degree, and columns 3 and 6 measure any college education.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_4.tex"), sep="\n")


# Table 5: Appointing Local Election Officials Increases Citizen Participation Especially in Small Counties (Even-Year General Elections, 1968-2022)
regsize1x <- feols(turnout_pc ~ appointed + appointedXsmall | year_state_small + fips, cluster = "fips_small", data=dat)
regsize2x <- feols(turnout_pc ~ appointed + appointedXsmall | year_state_demvs_small + fips, cluster = "fips_small", data=dat)
regsize3x <- feols(turnout_pc ~ appointed + appointedXsmall | year_state_pop + fips, cluster = "fips_small", data=dat)
regsize1xf <- feols(reg_pc ~ appointed + appointedXsmall | year_state_small + fips, cluster = "fips_small", data=filter(dat, reg_separate == 0))
regsize2xf <- feols(reg_pc ~ appointed + appointedXsmall | year_state_demvs_small + fips, cluster = "fips_small", data=filter(dat, reg_separate == 0))
regsize3xf <- feols(reg_pc ~ appointed + appointedXsmall | year_state_pop + fips, cluster = "fips_small", data=filter(dat, reg_separate == 0))

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Appointing Local Election Officials Increases Citizen Participation Especially in Small Counties (Even-Year General Elections, 1968-2022)}",
  "\\label{tab:citizen_participation_pop_alt}}",
  "\\begin{tabular}{lcccccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{3}{c}{Voter Turnout} & \\multicolumn{3}{c}{Registration Rate}\\\\",
  " & (1) & (2) & (3) & (4) & (5) & (6)  \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f \\\\", regsize1x$coefficients[1], regsize2x$coefficients[1], regsize3x$coefficients[1], regsize1xf$coefficients[1], regsize2xf$coefficients[1], regsize3xf$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regsize1x$se[1], regsize2x$se[1], regsize3x$se[1], regsize1xf$se[1], regsize2xf$se[1], regsize3xf$se[1]),
  sprintf("Appointed X Small County & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", regsize1x$coefficients[2], regsize2x$coefficients[2], regsize3x$coefficients[2], regsize1xf$coefficients[2], regsize2xf$coefficients[2], regsize3xf$coefficients[2]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f)  \\\\[2mm]", regsize1x$se[2], regsize2x$se[2], regsize3x$se[2], regsize1xf$se[2], regsize2xf$se[2], regsize3xf$se[2]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f   \\\\", fitstat(regsize1x,"G"), fitstat(regsize2x,"G"), fitstat(regsize3x,"G"), fitstat(regsize1xf,"G"), fitstat(regsize2xf,"G"), fitstat(regsize3xf,"G")),
  sprintf("Elections & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", regsize1x$fixef_sizes[1]/26, ceiling(regsize2x$fixef_sizes[1]/104), regsize3x$fixef_sizes[1]/52, regsize1xf$fixef_sizes[1]/22, regsize2xf$fixef_sizes[1]/88, regsize3xf$fixef_sizes[1]/44),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f   \\\\", regsize1x$nobs, regsize2x$nobs, regsize3x$nobs, regsize1xf$nobs, regsize2xf$nobs, regsize3xf$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f  \\\\", fitstat(regsize1x,"my"), fitstat(regsize2x,"my"), fitstat(regsize3x,"my"), fitstat(regsize1xf,"my"), fitstat(regsize2xf,"my"), fitstat(regsize3xf,"my")),
  "County FEs & Yes & Yes & Yes & Yes & Yes & Yes  \\\\",
  "Year x State x Small FEs & Yes & No  &  No & Yes & No & No  \\\\",
  "Year x State x Dem vs x Small FEs & No & Yes & No & No & Yes & No  \\\\",
  "Year x State x Pop FEs & No & No & Yes & No & No & Yes  \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{7}{p{1\\textwidth}}{\\footnotesize Small counties rank in the bottom half in population compared to other counties within the same state. Robust standard errors clustered by county in parentheses. The number of observations is smaller in columns 3-4 because Arizona and Georgia are excluded and because turnout data is available from 1968 but registration data is only available from 1996.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_5.tex"), sep="\n")


# Table 6: Consistent Presence of a Daily Local Newspaper Attenuates the Effect of Appointing Local Election Officials on Citizen Participation (Even-Year General Elections, 1968-2022)
regnews1 <- feols(turnout_pc ~ appointed + appointedXnews | year_state_news + fips, cluster = "fips_news", data=dat)
regnews2 <- feols(turnout_pc ~ appointed + appointedXnews | year_state_demvs_news + fips, cluster = "fips_news", data=dat)
regnews3 <- feols(turnout_pc ~ appointed + appointedXnews | year_state_pop_news + fips, cluster = "fips_news", data=dat)
regnews1f <- feols(reg_pc ~ appointed + appointedXnews | year_state_news + fips, cluster = "fips_news", data=filter(dat, reg_separate == 0))
regnews2f <- feols(reg_pc ~ appointed + appointedXnews | year_state_demvs_news + fips, cluster = "fips_news", data=filter(dat, reg_separate == 0))
regnews3f <- feols(reg_pc ~ appointed + appointedXnews | year_state_pop_news + fips, cluster = "fips_news", data=filter(dat, reg_separate == 0))

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Consistent Presence of a Daily Local Newspaper Attenuates the Effect of Appointing Local Election Officials on Citizen Participation (Even-Year General Elections, 1968-2022)}",
  "\\label{tab:citizen_participation_news}}",
  "\\begin{tabular}{lcccccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{3}{c}{Voter Turnout} & \\multicolumn{3}{c}{Registration Rate}\\\\",
  " & (1) & (2) & (3) & (4) & (5) & (6) \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", regnews1$coefficients[1], regnews2$coefficients[1], regnews3$coefficients[1], regnews1f$coefficients[1], regnews2f$coefficients[1], regnews3f$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regnews1$se[1], regnews2$se[1], regnews3$se[1], regnews1f$se[1], regnews2f$se[1], regnews3f$se[1]),
  sprintf("Appointed X Newspaper & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", regnews1$coefficients[2], regnews2$coefficients[2], regnews3$coefficients[2], regnews1f$coefficients[2], regnews2f$coefficients[2], regnews3f$coefficients[2]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regnews1$se[2], regnews2$se[2], regnews3$se[2], regnews1f$se[2], regnews2f$se[2], regnews3f$se[2]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", fitstat(regnews1,"G"), fitstat(regnews2,"G"), fitstat(regnews3,"G"), fitstat(regnews1f,"G"), fitstat(regnews2f,"G"), fitstat(regnews3f,"G")),
  sprintf("Elections & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", 14, 14, 14, 6, 6, 6),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", regnews1$nobs, regnews2$nobs, regnews3$nobs, regnews1f$nobs, regnews2f$nobs, regnews3f$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f \\\\", fitstat(regnews1,"my"), fitstat(regnews2,"my"), fitstat(regnews3,"my"), fitstat(regnews1f,"my"), fitstat(regnews2f,"my"), fitstat(regnews3f,"my")),
  "County FEs & Yes & Yes & Yes & Yes & Yes & Yes \\\\",
  "Year x State x Newspaper FEs & Yes & No & No & Yes & No & No  \\\\",
  "Year x State x Dem vs x Newspaper FEs & No & Yes & No & No & Yes & No \\\\",
  "Year x State x Pop x Newspaper FEs & No & No & Yes & No & No & Yes \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{7}{p{1.05\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses. All counties that switch between having and not having a daily newspaper over the period of analysis are dropped. The number of observations is smaller in columns 4-6 because Arizona and Georgia are excluded and because turnout data is available from 1968 but registration data is only available from 1996.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_6.tex"), sep="\n")


# Table 7: Appointed Local Election Officials Turnover at Higher Rates Than Elected Officials (2004-2022)
## Create dataset that removes the observation when a county switch happens, since that causes turnover
dat_temp <- read.csv("../raw_data/dat_extended.csv") %>% 
  group_by(fips) %>% 
  arrange(fips, year) %>% 
  mutate(cohort = if_else(appointed == 1, year, max(year)+2)) %>% 
  slice(which.min(cohort)) %>% 
  select(fips, cohort) %>% 
  mutate(cohort = ifelse(cohort == 2024, 0, cohort))

dat_turnover <- left_join(dat_temp, read.csv("../raw_data/dat_extended.csv"), by = "fips") %>% 
  mutate(turnover_alt = ifelse(year == cohort & appointed == 1, NA, turnover),
         turnover2_alt = ifelse(year == cohort & appointed == 1, NA, turnover2),
         turnover_lag_alt = ifelse(year == cohort & appointed == 1, NA, turnover_lag),
         turnover2_lag_alt = ifelse(year == cohort & appointed == 1, NA, turnover2_lag),
         turnout_pc_lag = lag(turnout_pc),
         turnout_pc_lag4 = lag(turnout_pc_lag),
         appointed_lag = lag(appointed))

regtempax <- feols(turnover2_alt ~ appointed| year_state + fips, cluster = "fips",
                   data=filter(dat_turnover, state %in% c("AZ", "CA", "GA", "IL", "IN", "MN", "MO", "MT", "NE", "NV", "OR", "TX", "WA")))

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Appointed Local Elections Officials Turnover At Higher Rates Than Elected Officials (2004-2022)}",
  "\\label{tab:turnover_slim}}",
  "\\begin{tabular}{lc}",
  "\\toprule \\toprule",
  " & Election Official Turnover \\\\",
  " & (1)   \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f  \\\\", regtempax$coefficients[1]),
  sprintf(" & (%1.3f)  \\\\[2mm]", regtempax$se[1]),
  "\\midrule",
  sprintf("Counties & %4.0f   \\\\", fitstat(regtempax,"G")),
  sprintf("Elections & %4.0f  \\\\", regtempax$fixef_sizes[1]/41),
  sprintf("Observations & %4.0f   \\\\", regtempax$nobs),
  sprintf("Outcome Mean & %1.2f   \\\\", fitstat(regtempax,"my")),
  "County FEs & Yes  \\\\",
  "Year x State FEs & Yes  \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{2}{p{.5\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_7.tex"), sep="\n")


# Table A.1: Description of Counties In and Not In Sample
## Prep data (combining administrative data, census data, and Ferrer and Geyn 2024)
descriptives <- dat %>% 
  filter(divided_jurisdiction != 1) %>% 
  mutate(in_sample = 1) %>% 
  select(year, fips, appointed, evertreated, cohort, in_sample) %>% 
  right_join(read.csv("../raw_data/county_demos_dat.csv")) %>% 
  filter(year == 2020) %>% 
  mutate(in_sample = ifelse(is.na(in_sample), 0, in_sample)) %>% 
  left_join(read.csv("../raw_data/ferrer_geyn_2024_dat.csv"), by = "fips") %>% 
  mutate(appointed = coalesce(appointed.x, appointed.y)) %>% 
  select(-appointed.x, -appointed.y) %>% 
  group_by(fips) %>% 
  slice_max(votes) %>% 
  ungroup()

## Create table
desc_summary <- descriptives %>% 
  group_by(in_sample) %>% 
  summarise(pop_thousands = mean(pop, na.rm = T)/1000,
            pop_sd = sd(pop/1000, na.rm = T),
            dem_vs_avg = mean(dem_vs, na.rm = T),
            dem_vs_sd = sd(dem_vs, na.rm = T),
            turnout = mean(turnout_pc, na.rm = T),
            turnout_sd = sd(turnout_pc, na.rm = T),
            reg = mean(reg_pc, na.rm = T),
            reg_sd = sd(reg_pc, na.rm = T),
            share_nhwhite_avg = mean(share_nhwhite, na.rm = T),
            share_nhwhite_sd = sd(share_nhwhite, na.rm = T),
            share_black_avg = mean(share_black, na.rm = T),
            share_black_sd = sd(share_black, na.rm = T),
            share_hisp_avg = mean(share_hisp, na.rm = T),
            share_hisp_sd = sd(share_hisp, na.rm = T),
            northeast = mean(region_ne, na.rm = T),
            midwest = mean(region_mw, na.rm = T),
            south = mean(region_s, na.rm = T),
            west = mean(region_w, na.rm = T),
            share_appointed = mean(appointed, na.rm = T),
            share_partisan = mean(partisan_bin, na.rm = T),
            counties = length(unique(fips))) %>% 
  t() %>% 
  as_tibble(rownames = NA) %>% 
  rename(`In Sample` = V2, 
         `Not In Scope` = V1) %>%
  slice(-1) 

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Description of Counties In and Not In Sample}",
  "\\label{tab:descriptive_sample}}",
  "\\begin{tabular}{lcc}",
  "\\toprule \\toprule",
  " & In Sample & Not In Sample \\\\",
  " & (1) & (2) \\\\",
  "\\midrule",
  sprintf("Population (Thousdands) & %1.2f & %1.2f  \\\\", desc_summary[1,2], desc_summary[1,1]),
  sprintf(" & (%1.2f) & (%1.2f) \\\\[2mm]", desc_summary[2,2], desc_summary[2,1]),
  sprintf("Dem Pres Vote Share & %1.2f & %1.2f  \\\\", desc_summary[3,2], desc_summary[3,1]),
  sprintf(" & (%1.2f) & (%1.2f) \\\\[2mm]", desc_summary[4,2], desc_summary[4,1]),
  sprintf("Voter Turnout & %1.2f & %1.2f  \\\\", desc_summary[5,2], desc_summary[5,1]),
  sprintf(" & (%1.2f) & (%1.2f) \\\\[2mm]", desc_summary[6,2], desc_summary[6,1]),
  sprintf("Voter Registration & %1.2f & %1.2f  \\\\", desc_summary[7,2], desc_summary[7,1]),
  sprintf(" & (%1.2f) & (%1.2f) \\\\[2mm]", desc_summary[8,2], desc_summary[8,1]),
  sprintf("Share Non-Hispanic White & %1.2f & %1.2f  \\\\", desc_summary[9,2], desc_summary[9,1]),
  sprintf(" & (%1.2f) & (%1.2f) \\\\[2mm]", desc_summary[10,2], desc_summary[10,1]),
  sprintf("Share Black & %1.3f & %1.3f  \\\\", desc_summary[11,2], desc_summary[11,1]),
  sprintf(" & (%1.2f) & (%1.2f) \\\\[2mm]", desc_summary[12,2], desc_summary[12,1]),
  sprintf("Share Hispanic & %1.2f & %1.2f  \\\\", desc_summary[13,2], desc_summary[13,1]),
  sprintf(" & (%1.2f) & (%1.2f) \\\\[2mm]", desc_summary[14,2], desc_summary[14,1]),
  sprintf("Northeast & %1.2f & %1.2f  \\\\", desc_summary[15,2], desc_summary[15,1]),
  sprintf("Midwest & %1.2f & %1.2f  \\\\", desc_summary[16,2], desc_summary[16,1]),
  sprintf("South & %1.2f & %1.2f  \\\\", desc_summary[17,2], desc_summary[17,1]),
  sprintf("West & %1.2f & %1.2f  \\\\", desc_summary[18,2], desc_summary[18,1]),
  sprintf("Share Appointed & %1.2f & %1.2f  \\\\", desc_summary[19,2], desc_summary[19,1]),
  sprintf("Num Counties & %1.0f & %1.0f  \\\\", desc_summary[21,2], desc_summary[21,1]),
  "\\midrule",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{3}{p{.6\\textwidth}}{\\footnotesize Standard deviations are reported in parentheses below group means. Counties for the 8 states with municipal-level election administration (CT, MA, ME, MI, NH, RI, VT, WI) are not included in the out-of-sample descriptive characteristics.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.1.tex"), sep="\n")

## "13 U.S. states that comprise nearly 40% of the country’s population"
sum(descriptives$pop[descriptives$in_sample == 1]) / sum(descriptives$pop)

# Table A.2: Local Election Official Selection Methods by State
entity_mapping <- tibble::tibble(
  state = c("AZ", "CA", "GA", "IL", "IN", "MN", "MO", "MT", "NE", "NV", "OR", "TX", "WA"),
  elected_entity = c("Election Administrator", "Clerk", "Probate Judge", "Clerk", "Clerk", "Auditor",
                     "Clerk", "Clerk and Recorder", "Clerk", "Clerk", "Clerk", "Clerk / Tax Assessor", "Auditor"),
  appointed_entity = c("Recorder", "Registrar of Voters / Clerk", "Board of Elections and Registration",
                       "Election Commission", "Board of Election and Registration", "Auditor",
                       "Election Commission / Director of Elections", "Election Administrator / Clerk and Recorder",
                       "Election Commissioner", "Registrar of Voters", "Elections Manager/Director",
                       "Elections Administrator", "Elections Director"))

leo_info <- dat %>% 
  group_by(fips) %>% 
  slice(1) %>% 
  mutate(elect_to_appoint = ifelse(multiple_switches == 1, 0, elect_to_appoint),
         appoint_to_elect = ifelse(multiple_switches == 1, 0, appoint_to_elect),
         cohort = ifelse(cohort == 0 | cohort == 1960, NA, cohort)) %>% 
  group_by(state_abr) %>% 
  summarise(counties = n(),
            `Always Appointed` = sum(always_appointed, na.rm = T),
            `Always Elected` = sum(always_elected, na.rm = T),
            `To Appointed` = sum(elect_to_appoint, na.rm = T),
            `To Elected` = sum(appoint_to_elect, na.rm = T),
            `Multiple Switches` = sum(multiple_switches, na.rm = T),
            `First Switch` = min(cohort, na.rm = T),
            `Last Switch` = max(cohort, na.rm = T)) %>% 
  mutate(`Last Switch` = ifelse(state_abr == "WA", 2009, `Last Switch`))  # correcting for multiple switch county latest switch 
  
leo_info <- leo_info %>%
  rename(state = state_abr) %>% 
  left_join(entity_mapping, by = "state") %>% 
  relocate(elected_entity, appointed_entity, .after = state) %>% 
  rename(`State` = state,
         `Elected Entity` = elected_entity,
         `Appointed Entity` = appointed_entity,
         Counties = counties)
    
  totals_row <- leo_info %>% 
    summarise(`State` = "Totals",
              `Elected Entity` = "-",
              `Appointed Entity` = "-", 
              Counties = sum(Counties, na.rm = TRUE),
              `Always Appointed` = sum(`Always Appointed`, na.rm = TRUE),
              `Always Elected` = sum(`Always Elected`, na.rm = TRUE),
              `To Appointed` = sum(`To Appointed`, na.rm = TRUE),
              `To Elected` = sum(`To Elected`, na.rm = TRUE),
              `Multiple Switches` = sum(`Multiple Switches`, na.rm = TRUE),
              `First Switch` = NA,
              `Last Switch` = NA)

# Bind the totals row to the main dataframe
leo_info <- bind_rows(leo_info, totals_row) %>% 
  mutate(`First Switch` = ifelse(is.na(`First Switch`), "-", `First Switch`),
         `Last Switch` = ifelse(is.na(`Last Switch`), "-", `Last Switch`))

sink("../output/tables/Table_A.2.tex")
kable(leo_info, format = "latex", booktabs = TRUE, longtable = TRUE)
sink()

## "99.1% of counties switching their selection method have adopted appointments"
leo_info$`To Appointed`[14]/(leo_info$`To Appointed`[14]+leo_info$`To Elected`[14])

## "93% of all singular switches have been in the direction of appointments"
sum(dat$appointed0, na.rm = T)/(sum(dat$appointed0, na.rm = T)  + sum(dat$elected0, na.rm = T))


# Table A.3: Description of Appointed and Elected Counties
## Run lines 363--375 above first

desc_summary_sm <- descriptives %>% 
  filter(!is.na(appointed)) %>%  
  group_by(appointed) %>% 
  summarise(pop_thousands = mean(pop, na.rm = T)/1000,
            pop_sd = sd(pop/1000, na.rm = T),
            dem_vs_avg = mean(dem_vs, na.rm = T),
            dem_vs_sd = sd(dem_vs, na.rm = T),
            turnout = mean(turnout_pc, na.rm = T),
            turnout_sd = sd(turnout_pc, na.rm = T),
            reg = mean(reg_pc, na.rm = T),
            reg_sd = sd(reg_pc, na.rm = T),
            share_nhwhite_avg = mean(share_nhwhite, na.rm = T),
            share_nhwhite_sd = sd(share_nhwhite, na.rm = T),
            share_black_avg = mean(share_black, na.rm = T),
            share_black_sd = sd(share_black, na.rm = T),
            share_hisp_avg = mean(share_hisp, na.rm = T),
            share_hisp_sd = sd(share_hisp, na.rm = T),
            northeast = mean(region_ne, na.rm = T),
            midwest = mean(region_mw, na.rm = T),
            south = mean(region_s, na.rm = T),
            west = mean(region_w, na.rm = T),
            share_partisan = mean(partisan_bin, na.rm = T),
            counties = length(unique(fips))) %>% 
  t() %>% 
  as_tibble(rownames = NA) %>% 
  rename(`Appointed` = V2, 
         `Elected` = V1) %>%
  slice(-1)

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Description of Appointed and Elected Counties}",
  "\\label{tab:descriptive_selection}}",
  "\\begin{tabular}{lcc}",
  "\\toprule \\toprule",
  " & Appointed & Elected \\\\",
  " & (1) & (2) \\\\",
  "\\midrule",
  sprintf("Population (Thousdands) & %1.2f & %1.2f  \\\\", desc_summary_sm[1,2], desc_summary_sm[1,1]),
  sprintf(" & (%1.2f) & (%1.2f) \\\\[2mm]", desc_summary_sm[2,2], desc_summary_sm[2,1]),
  sprintf("Dem Pres Vote Share & %1.2f & %1.2f  \\\\", desc_summary_sm[3,2], desc_summary_sm[3,1]),
  sprintf(" & (%1.2f) & (%1.2f) \\\\[2mm]", desc_summary_sm[4,2], desc_summary_sm[4,1]),
  sprintf("Voter Turnout & %1.2f & %1.2f  \\\\", desc_summary_sm[5,2], desc_summary_sm[5,1]),
  sprintf(" & (%1.2f) & (%1.2f) \\\\[2mm]", desc_summary_sm[6,2], desc_summary_sm[6,1]),
  sprintf("Voter Registration & %1.2f & %1.2f  \\\\", desc_summary_sm[7,2], desc_summary_sm[7,1]),
  sprintf(" & (%1.2f) & (%1.2f) \\\\[2mm]", desc_summary_sm[8,2], desc_summary_sm[8,1]),
  sprintf("Share Non-Hispanic White & %1.2f & %1.2f  \\\\", desc_summary_sm[9,2], desc_summary_sm[9,1]),
  sprintf(" & (%1.2f) & (%1.2f) \\\\[2mm]", desc_summary_sm[10,2], desc_summary_sm[10,1]),
  sprintf("Share Black & %1.2f & %1.2f  \\\\", desc_summary_sm[11,2], desc_summary_sm[11,1]),
  sprintf(" & (%1.2f) & (%1.2f) \\\\[2mm]", desc_summary_sm[12,2], desc_summary_sm[12,1]),
  sprintf("Share Hispanic & %1.2f & %1.2f  \\\\", desc_summary_sm[13,2], desc_summary_sm[13,1]),
  sprintf(" & (%1.2f) & (%1.2f) \\\\[2mm]", desc_summary_sm[14,2], desc_summary_sm[14,1]),
  sprintf("Northeast & %1.2f & %1.2f  \\\\", desc_summary_sm[15,2], desc_summary_sm[15,1]),
  sprintf("Midwest & %1.2f & %1.2f  \\\\", desc_summary_sm[16,2], desc_summary_sm[16,1]),
  sprintf("South & %1.2f & %1.2f  \\\\", desc_summary_sm[17,2], desc_summary_sm[17,1]),
  sprintf("West & %1.2f & %1.2f  \\\\", desc_summary_sm[18,2], desc_summary_sm[18,1]),
  sprintf("Num Counties & %1.0f & %1.0f  \\\\", desc_summary_sm[20,2], desc_summary_sm[20,1]),
  "\\midrule",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{3}{p{.6\\textwidth}}{\\footnotesize Standard deviations are reported in parentheses below group means. Counties for the 8 states with municipal-level election administration (CT, MA, ME, MI, NH, RI, VT, WI) are not included.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.3.tex"), sep="\n")


# Table A.4: Description of Elected To Appointed and Always Elected Counties
## Run lines 363--375 above first

desc_summary_tc <- descriptives %>% 
  filter(in_sample == 1) %>% 
  left_join(dat %>% filter(year == 2020) %>%  select(fips, always_elected, elect_to_appoint), by = "fips") %>% 
  filter(always_elected == 1 | elect_to_appoint == 1) %>% 
  group_by(elect_to_appoint) %>% 
  summarise(pop_thousands = mean(pop, na.rm = T)/1000,
            pop_sd = sd(pop/1000, na.rm = T),
            dem_vs_avg = mean(dem_vs, na.rm = T),
            dem_vs_sd = sd(dem_vs, na.rm = T),
            turnout = mean(turnout_pc, na.rm = T),
            turnout_sd = sd(turnout_pc, na.rm = T),
            reg = mean(reg_pc, na.rm = T),
            reg_sd = sd(reg_pc, na.rm = T),
            share_nhwhite_avg = mean(share_nhwhite, na.rm = T),
            share_nhwhite_sd = sd(share_nhwhite, na.rm = T),
            share_black_avg = mean(share_black, na.rm = T),
            share_black_sd = sd(share_black, na.rm = T),
            share_hisp_avg = mean(share_hisp, na.rm = T),
            share_hisp_sd = sd(share_hisp, na.rm = T),
            northeast = mean(region_ne, na.rm = T),
            midwest = mean(region_mw, na.rm = T),
            south = mean(region_s, na.rm = T),
            west = mean(region_w, na.rm = T),
            share_partisan = mean(partisan_bin, na.rm = T),
            counties = length(unique(fips))) %>% 
  t() %>% 
  as_tibble(rownames = NA) %>% 
  rename(`Elected to Appointed` = V2, 
         `Always Elected` = V1) %>%
  slice(-1)

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Description of Elected To Appointed and Always Elected Counties}",
  "\\label{tab:descriptive_treatment}}",
  "\\begin{tabular}{lcc}",
  "\\toprule \\toprule",
  " & Elected to Appointed & Always Elected \\\\",
  " & (1) & (2) \\\\",
  "\\midrule",
  sprintf("Population (Thousdands) & %1.2f & %1.2f  \\\\", desc_summary_tc[1,2], desc_summary_tc[1,1]),
  sprintf(" & (%1.2f) & (%1.2f) \\\\[2mm]", desc_summary_tc[2,2], desc_summary_tc[2,1]),
  sprintf("Dem Pres Vote Share & %1.2f & %1.2f  \\\\", desc_summary_tc[3,2], desc_summary_tc[3,1]),
  sprintf(" & (%1.2f) & (%1.2f) \\\\[2mm]", desc_summary_tc[4,2], desc_summary_tc[4,1]),
  sprintf("Voter Turnout & %1.2f & %1.2f  \\\\", desc_summary_tc[5,2], desc_summary_tc[5,1]),
  sprintf(" & (%1.2f) & (%1.2f) \\\\[2mm]", desc_summary_tc[6,2], desc_summary_tc[6,1]),
  sprintf("Voter Registration & %1.2f & %1.2f  \\\\", desc_summary_tc[7,2], desc_summary_tc[7,1]),
  sprintf(" & (%1.2f) & (%1.2f) \\\\[2mm]", desc_summary_tc[8,2], desc_summary_tc[8,1]),
  sprintf("Share Non-Hispanic White & %1.2f & %1.2f  \\\\", desc_summary_tc[9,2], desc_summary_tc[9,1]),
  sprintf(" & (%1.2f) & (%1.2f) \\\\[2mm]", desc_summary_tc[10,2], desc_summary_tc[10,1]),
  sprintf("Share Black & %1.2f & %1.2f  \\\\", desc_summary_tc[11,2], desc_summary_tc[11,1]),
  sprintf(" & (%1.2f) & (%1.2f) \\\\[2mm]", desc_summary_tc[12,2], desc_summary_tc[12,1]),
  sprintf("Share Hispanic & %1.2f & %1.2f  \\\\", desc_summary_tc[13,2], desc_summary_tc[13,1]),
  sprintf(" & (%1.2f) & (%1.2f) \\\\[2mm]", desc_summary_tc[14,2], desc_summary_tc[14,1]),
  sprintf("Northeast & %1.2f & %1.2f  \\\\", desc_summary_tc[15,2], desc_summary_tc[15,1]),
  sprintf("Midwest & %1.2f & %1.2f  \\\\", desc_summary_tc[16,2], desc_summary_tc[16,1]),
  sprintf("South & %1.2f & %1.2f  \\\\", desc_summary_tc[17,2], desc_summary_tc[17,1]),
  sprintf("West & %1.2f & %1.2f  \\\\", desc_summary_tc[18,2], desc_summary_tc[18,1]),
  sprintf("Num Counties & %1.0f & %1.0f  \\\\", desc_summary_tc[20,2], desc_summary_tc[20,1]),
  "\\midrule",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{3}{p{.75\\textwidth}}{\\footnotesize Standard deviations are reported in parentheses below group means. Counties for the 8 states with municipal-level election administration (CT, MA, ME, MI, NH, RI, VT, WI) are not included.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.4.tex"), sep="\n")


# Table A.5: Appointing Local Election Officials Increases Citizen Participation (Presidential Elections, 1968-2020)
reg1 <- feols(turnout_pc ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, cycle == "pres"))
reg1a <- feols(turnout_pc ~ appointed | year_state_demvs + fips, cluster = "fips", data=filter(dat, cycle == "pres"))
reg1b <- feols(turnout_pc ~ appointed | year_state_pop + fips, cluster = "fips", data=filter(dat, cycle == "pres"))
reg7wo <- feols(reg_pc ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, reg_separate == 0 & cycle == "pres"))
reg7woa <- feols(reg_pc ~ appointed | year_state_demvs + fips, cluster = "fips", data=filter(dat, reg_separate == 0 & cycle == "pres"))
reg7wob <- feols(reg_pc ~ appointed | year_state_pop + fips, cluster = "fips", data=filter(dat, reg_separate == 0 & cycle == "pres"))

cat(
  "\\begin{table}[h!]",
  "\\centering", 
  "\\caption{\\textbf{Appointing Local Election Officials Increases Citizen Participation (Presidential Elections, 1968-2020)}",
  "\\label{tab:citizen_participation}}",
  "\\begin{tabular}{lcccccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{3}{c}{Voter Turnout} & \\multicolumn{3}{c}{Registration Rate}\\\\",
  " & (1) & (2) & (3) & (4) & (5) & (6) \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", reg1$coefficients[1], reg1a$coefficients[1], reg1b$coefficients[1], reg7wo$coefficients[1], reg7woa$coefficients[1], reg7wob$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", reg1$se[1], reg1a$se[1], reg1b$se[1], reg7wo$se[1], reg7woa$se[1], reg7wob$se[1]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", fitstat(reg1,"G"), fitstat(reg1a,"G"), fitstat(reg1b,"G"), fitstat(reg7wo,"G"), fitstat(reg7woa,"G"), fitstat(reg7wob,"G")),
  sprintf("Elections & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", reg1$fixef_sizes[1]/13, reg1a$fixef_sizes[1]/52, reg1b$fixef_sizes[1]/52, reg7wo$fixef_sizes[1]/12, reg7woa$fixef_sizes[1]/48, reg7wob$fixef_sizes[1]/48),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", reg1$nobs, reg1a$nobs, reg1b$nobs, reg7wo$nobs, reg7woa$nobs, reg7wob$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f \\\\", fitstat(reg1,"my"), fitstat(reg1a,"my"), fitstat(reg1b,"my"), fitstat(reg7wo,"my"), fitstat(reg7woa,"my"), fitstat(reg7wob,"my")),
  "County FEs & Yes & Yes & Yes & Yes & Yes & Yes \\\\",
  "Year x State FEs & Yes & No & No & Yes & No & No  \\\\",
  "Year x State x Dem vote share FEs & No & Yes & No & No & Yes & No \\\\",
  "Year x State x Population FEs & No & No & Yes & No & No & Yes \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{7}{p{1\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses. Voter turnout and registration rate are measured as proportions out of 1. The number of observations is smaller in columns 4-6 because Arizona and Georgia are excluded and because turnout data is available from 1968 but registration data is only available from 1996.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.5.tex"), sep="\n")


# Table A.6: Appointing Local Election Officials Increases Citizen Participation (Even-Year General Elections, 1968-2020, Public Information Act Preferenced)
regr1 <- feols(turnout_pc ~ appointed_noimp | year_state + fips, cluster = "fips", data=dat)
regr1a <- feols(turnout_pc ~ appointed_noimp | year_state_demvs + fips, cluster = "fips", data=dat)
regr1b <- feols(turnout_pc ~ appointed_noimp | year_state_pop + fips, cluster = "fips", data=dat)
regr2wo <- feols(reg_pc ~ appointed_noimp | year_state + fips, cluster = "fips", data=filter(dat, reg_separate == 0))
regr2woa <- feols(reg_pc ~ appointed_noimp | year_state_demvs + fips, cluster = "fips", data=filter(dat, reg_separate == 0))
regr2wob  <- feols(reg_pc ~ appointed_noimp | year_state_pop + fips, cluster = "fips", data=filter(dat, reg_separate == 0))

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Appointing Local Election Officials Increases Citizen Participation (Even-Year General Elections, 1968-2022, Public Information Act Preferenced)}",
  "\\label{tab:citizen_participation_alt}}",
  "\\begin{tabular}{lcccccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{3}{c}{Voter Turnout} & \\multicolumn{3}{c}{Registration Rate}\\\\",
  " & (1) & (2) & (3) & (4) & (5) & (6) \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", regr1$coefficients[1], regr1a$coefficients[1], regr1b$coefficients[1], regr2wo$coefficients[1], regr2woa$coefficients[1], regr2wob$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regr1$se[1], regr1a$se[1], regr1b$se[1], regr2wo$se[1], regr2woa$se[1], regr2wob$se[1]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", fitstat(regr1,"G"), fitstat(regr1a,"G"), fitstat(regr1b,"G"), fitstat(regr2wo,"G"), fitstat(regr2woa,"G"), fitstat(regr2wob,"G")),
  sprintf("Elections & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", regr1$fixef_sizes[1]/13, regr1a$fixef_sizes[1]/52, regr1b$fixef_sizes[1]/52, regr2wo$fixef_sizes[1]/11, regr2woa$fixef_sizes[1]/44, regr2wob$fixef_sizes[1]/44),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", regr1$nobs, regr1a$nobs, regr1b$nobs, regr2wo$nobs, regr2woa$nobs, regr2wob$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f \\\\", fitstat(regr1,"my"), fitstat(regr1a,"my"), fitstat(regr1b,"my"), fitstat(regr2wo,"my"), fitstat(regr2woa,"my"), fitstat(regr2wob,"my")),
  "County FEs & Yes & Yes & Yes & Yes & Yes & Yes \\\\",
  "Year x State FEs & Yes & No & No & Yes & No & No  \\\\",
  "Year x State x Dem vote share FEs & No & Yes & No & No & Yes & No \\\\",
  "Year x State x Population FEs & No & No & Yes & No & No & Yes \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{7}{p{1\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses. The number of observations is smaller in columns 4-6 because Arizona and Georgia are excluded and because turnout data is available from 1968 but registration data is available from 1996.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.6.tex"), sep="\n")


# Table A.7: Finding that Appointing Local Election Officials Increases Voter Turnout is Robust to Including County Time Trends
reg_tt1 <- feols(turnout_pc ~ appointed| year_state + fips[year], cluster = "fips", data=dat)
reg_tt1a <- feols(turnout_pc ~ appointed| year_state_demvs + fips[year], cluster = "fips", data=dat)
reg_tt1b <- feols(turnout_pc ~ appointed| year_state_pop + fips[year], cluster = "fips", data=dat)
reg_tt7 <- feols(reg_pc ~ appointed| year_state + fips[year], cluster = "fips", data=filter(dat, reg_separate == 0))
reg_tt7a <- feols(reg_pc ~ appointed| year_state_demvs + fips[year], cluster = "fips", data=filter(dat, reg_separate == 0))
reg_tt7b <- feols(reg_pc ~ appointed| year_state_pop + fips[year], cluster = "fips", data=filter(dat, reg_separate == 0))

cat(
  "\\begin{table}[h!]",
  "\\centering", 
  "\\caption{\\textbf{Finding that Appointing Local Election Officials Increases Voter Turnout is Robust to Including County Time Trends}",
  "\\label{tab:citizen_participation_full_timetrend}}",
  "\\begin{tabular}{lcccccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{3}{c}{Voter Turnout} & \\multicolumn{3}{c}{Registration Rate}\\\\",
  " & (1) & (2) & (3) & (4) & (5) & (6) \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", reg_tt1$coefficients[1], reg_tt1a$coefficients[1], reg_tt1b$coefficients[1], reg_tt7$coefficients[1], reg_tt7a$coefficients[1], reg_tt7b$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", reg_tt1$se[1], reg_tt1a$se[1], reg_tt1b$se[1], reg_tt7$se[1], reg_tt7a$se[1], reg_tt7b$se[1]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", fitstat(reg_tt1,"G"), fitstat(reg_tt1a,"G"), fitstat(reg_tt1b,"G"), fitstat(reg_tt7,"G"), fitstat(reg_tt7a,"G"), fitstat(reg_tt7b,"G")),
  sprintf("Elections & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", reg_tt1$fixef_sizes[1]/13, reg_tt1a$fixef_sizes[1]/52, reg_tt1b$fixef_sizes[1]/52, reg_tt7$fixef_sizes[1]/11, reg_tt7a$fixef_sizes[1]/44, reg_tt7b$fixef_sizes[1]/44),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", reg_tt1$nobs, reg_tt1a$nobs, reg_tt1b$nobs, reg_tt7$nobs, reg_tt7a$nobs, reg_tt7b$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f \\\\", fitstat(reg_tt1,"my"), fitstat(reg_tt1a,"my"), fitstat(reg1bf,"my"), fitstat(reg7wof,"my"), fitstat(reg_tt7a,"my"), fitstat(reg_tt7b,"my")),
  "County FEs & Yes & Yes & Yes & Yes & Yes & Yes \\\\",
  "Year x State FEs & Yes & No & No & Yes & No & No  \\\\",
  "Year x State x Dem vs FEs & No & Yes & No & No & Yes & No \\\\",
  "Year x State x Pop FEs & No & No & Yes & No & No & Yes \\\\",
  "County Time Trend & Yes & Yes & Yes & Yes & Yes & Yes \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{7}{p{.925\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses. Voter turnout and registration rate are measured as proportions out of 1. The number of observations is smaller in columns 4-6 because Arizona and Georgia are excluded and because turnout data is available from 1968 but registration data is only available from 1996.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.7.tex"), sep="\n")


# Table A.8: Appointing Local Election Officials Increases Election Expenditures (Even-Year General Elections with Time Trends, 2004-2016)
regcostregt <- feols(log_expnd_per_reg ~ appointed | year_state + fips[year], cluster = "fips", data=dat)
regcostregat <- feols(log_expnd_per_reg ~ appointed | year_state_demvs + fips[year], cluster = "fips", data=dat)
regcostregbt <- feols(log_expnd_per_reg ~ appointed | year_state_pop + fips[year], cluster = "fips", data=dat)
regcostregxt <- feols(log_expnd_per_reg ~ appointed + appointedXsmall | year_state_small + fips_small[year], cluster = "fips_small", data=dat)
regcostregaxt <- feols(log_expnd_per_reg ~ appointed  + appointedXsmall| year_state_demvs_small + fips_small[year], cluster = "fips_small", data=dat)
regcostregbxt <- feols(log_expnd_per_reg ~ appointed + appointedXsmall | year_state_pop + fips_small[year], cluster = "fips_small", data=dat)

cat(
  "\\begin{table}[h!]",
  "\\centering", 
  "\\caption{\\textbf{Appointing Local Election Officials Increases Election Expenditures (Even-Year General Elections with Time Trends, 2004-2016)}",
  "\\label{tab:election_costs_sizett}}",
  "\\begin{tabular}{lcccccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{6}{c}{Ln(Total Election Expenditures Per Registered Voter)} \\\\",
  " & (1) & (2) & (3) & (4) & (5) & (6) \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", regcostregt$coefficients[1], regcostregat$coefficients[1], regcostregbt$coefficients[1], regcostregxt$coefficients[1], regcostregaxt$coefficients[1], regcostregbxt$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regcostregt$se[1], regcostregat$se[1], regcostregbt$se[1], regcostregxt$se[1], regcostregaxt$se[1], regcostregbxt$se[1]),
  sprintf("Appointed X Small County &  &  &  & %1.3f & %1.3f & %1.3f  \\\\", regcostregxt$coefficients[2], regcostregaxt$coefficients[2], regcostregbxt$coefficients[2]),
  sprintf(" &  &  &  & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regcostregxt$se[2], regcostregaxt$se[2], regcostregbxt$se[2]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", fitstat(regcostregt,"G"), fitstat(regcostregat,"G"), fitstat(regcostregbt,"G"), fitstat(regcostregxt,"G"), fitstat(regcostregaxt,"G"), fitstat(regcostregbxt,"G")),
  sprintf("Elections & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", floor(regcostregt$fixef_sizes[1]/7), floor(regcostregat$fixef_sizes[1]/28), floor(regcostregbt$fixef_sizes[1]/28), floor(regcostregxt$fixef_sizes[1]/14), regcostregaxt$fixef_sizes[1]/56, floor(regcostregbxt$fixef_sizes[1]/28)),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", regcostregt$nobs, regcostregat$nobs, regcostregbt$nobs, regcostregxt$nobs, regcostregaxt$nobs, regcostregbxt$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f \\\\", fitstat(regcostregt,"my"), fitstat(regcostregat,"my"), fitstat(regcostregbt,"my"), fitstat(regcostregxt,"my"), fitstat(regcostregaxt,"my"), fitstat(regcostregbxt,"my")),
  "County FEs & Yes & Yes & Yes & Yes & Yes & Yes \\\\",
  "Year x State FEs & Yes & No & No & No & No & No  \\\\",
  "Year x State x Dem vs FEs & No & Yes & No & No & No & No  \\\\",
  "Year x State x Pop FEs & No & No & Yes & No & No & Yes  \\\\",
  "Year x State x Small FEs & No & No & No & Yes & No & No  \\\\",
  "Year x State x Dem vs x Small FEs & No & No & No & No & Yes & No \\\\",
  "County Time Trend & Yes & Yes & Yes & Yes & Yes & Yes  \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{7}{p{1\\textwidth}}{\\footnotesize Small counties rank in the bottom half in population compared to other counties within the same state. Robust standard errors clustered by county in parentheses. Data is from Mohr et al. (2018) and is available for Arizona, California, Georgia, Minnesota, Missouri, Nebraska, and Nevada. Elections are the average number of elections included for each state, rounded down to the nearest interger. Expenditure data is normalized to 2020 dollars.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.8.tex"), sep="\n")


# Table A.9: Appointed Local Election Officials May Decrease Voter Wait Times (Even-Year General Elections with Time Trends, 2008-2022)
problems_dat <- read.csv("../raw_data/spae_cleaned.csv") %>% 
  inner_join(dat, by = c("fips", "year"))

regwaitiat <- feols(wait_min ~ appointed +  gender + as.factor(race) + birthyr + as.factor(educ) + as.factor(pid7)  | year_state + fips[year], cluster = "fips", weights = problems_dat$weight, data = problems_dat)
regwaitibt <- feols(wait_over_10 ~ appointed +  gender + as.factor(race) + birthyr + as.factor(educ) + as.factor(pid7)  | year_state + fips[year], cluster = "fips", weights = problems_dat$weight, data = problems_dat)
regwaitict <- feols(wait_over_30 ~ appointed +  gender + as.factor(race) + birthyr + as.factor(educ) + as.factor(pid7)  | year_state + fips[year], cluster = "fips", weights = problems_dat$weight, data = problems_dat)
regwaitidt <- feols(wait_over_1hr ~ appointed +  gender + as.factor(race) + birthyr + as.factor(educ) + as.factor(pid7)  | year_state + fips[year], cluster = "fips", weights = problems_dat$weight, data = problems_dat)

cat(
  "\\begin{table}[h!]",
  "\\centering", 
  "\\caption{\\textbf{Appointed Local Election Officials May Decrease Voter Wait Times (Even-Year General Elections with Time Trends, 2008-2022)}",
  "\\label{tab:wait_timestt}}",
  "\\begin{tabular}{lcccc}",
  "\\toprule \\toprule",
  " & Min Waited & $>$ 10 min & $>$ 30 min & $>$ 1 hr \\\\",
  " & (1) & (2) & (3) & (4) \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", regwaitiat$coefficients[1], regwaitibt$coefficients[1], regwaitict$coefficients[1], regwaitidt$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f)  \\\\[2mm]", regwaitiat$se[1], regwaitibt$se[1], regwaitict$se[1], regwaitidt$se[1]),
  sprintf("Counties & %4.0f & %4.0f & %4.0f  & %4.0f\\\\", fitstat(regwaitiat,"G"), fitstat(regwaitibt,"G"), fitstat(regwaitict,"G"), fitstat(regwaitidt,"G")),
  sprintf("Respondents & %4.0f & %4.0f & %4.0f  & %4.0f\\\\", fitstat(regwaitiat,"n"), fitstat(regwaitibt,"n"), fitstat(regwaitict,"n"), fitstat(regwaitidt,"n")),
  sprintf("Elections & %4.0f & %4.0f & %4.0f & %4.0f \\\\", regwaitiat$fixef_sizes[1]/13, regwaitibt$fixef_sizes[1]/13, regwaitict$fixef_sizes[1]/13, regwaitidt$fixef_sizes[1]/13),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f \\\\", regwaitiat$nobs, regwaitibt$nobs, regwaitict$nobs, regwaitidt$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f \\\\", fitstat(regwaitiat,"my"), fitstat(regwaitibt,"my"), fitstat(regwaitict,"my"), fitstat(regwaitidt,"my")),
  "County FEs & Yes & Yes & Yes & Yes  \\\\",
  "Year x State FEs & Yes & Yes & Yes & Yes \\\\",
  "Individual Controls & Yes & Yes & Yes & Yes \\\\",
  "County Time Trend & Yes & Yes & Yes & Yes  \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{5}{p{.7\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses. Individual controls are gender, race, age, education, and party identification.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.9.tex"), sep="\n")


# Table A.10: Appointing Local Election Officials Increases Citizen Participation Especially in Small Counties (Even-Year General Elections with Time Trends, 1968-2022)
regsize1xt <- feols(turnout_pc ~ appointed + appointedXsmall | year_state_small + fips[year], cluster = "fips_small", data=dat)
regsize2xt <- feols(turnout_pc ~ appointed + appointedXsmall | year_state_demvs_small + fips[year], cluster = "fips_small", data=dat)
regsize3xt <- feols(turnout_pc ~ appointed + appointedXsmall | year_state_pop + fips[year], cluster = "fips_small", data=dat)
regsize1xft <- feols(reg_pc ~ appointed + appointedXsmall | year_state_small + fips[year], cluster = "fips_small", data=filter(dat, reg_separate == 0))
regsize2xft <- feols(reg_pc ~ appointed + appointedXsmall | year_state_demvs_small + fips[year], cluster = "fips_small", data=filter(dat, reg_separate == 0))
regsize3xft <- feols(reg_pc ~ appointed + appointedXsmall | year_state_pop + fips[year], cluster = "fips_small", data=filter(dat, reg_separate == 0))

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Appointing Local Election Officials Increases Citizen Participation Especially in Small Counties (Even-Year General Elections with Time Trends, 1968-2022)}",
  "\\label{tab:citizen_participation_pop_alt_tt}}",
  "\\begin{tabular}{lcccccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{3}{c}{Voter Turnout} & \\multicolumn{3}{c}{Registration Rate}\\\\",
  " & (1) & (2) & (3) & (4) & (5) & (6)  \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f \\\\", regsize1xt$coefficients[1], regsize2xt$coefficients[1], regsize3xt$coefficients[1], regsize1xft$coefficients[1], regsize2xft$coefficients[1], regsize3xft$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regsize1xt$se[1], regsize2xt$se[1], regsize3xt$se[1], regsize1xft$se[1], regsize2xft$se[1], regsize3xft$se[1]),
  sprintf("Appointed X Small County & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", regsize1xt$coefficients[2], regsize2xt$coefficients[2], regsize3xt$coefficients[2], regsize1xft$coefficients[2], regsize2xft$coefficients[2], regsize3xft$coefficients[2]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f)  \\\\[2mm]", regsize1xt$se[2], regsize2xt$se[2], regsize3xt$se[2], regsize1xft$se[2], regsize2xft$se[2], regsize3xft$se[2]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f   \\\\", fitstat(regsize1xt,"G"), fitstat(regsize2xt,"G"), fitstat(regsize3xt,"G"), fitstat(regsize1xft,"G"), fitstat(regsize2xft,"G"), fitstat(regsize3xft,"G")),
  sprintf("Elections & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", regsize1xt$fixef_sizes[1]/26, ceiling(regsize2xt$fixef_sizes[1]/104), regsize3xt$fixef_sizes[1]/52, regsize1xft$fixef_sizes[1]/22, regsize2xft$fixef_sizes[1]/88, regsize3xft$fixef_sizes[1]/44),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f   \\\\", regsize1xt$nobs, regsize2xt$nobs, regsize3xt$nobs, regsize1xft$nobs, regsize2xft$nobs, regsize3xft$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f  \\\\", fitstat(regsize1xt,"my"), fitstat(regsize2xt,"my"), fitstat(regsize3xt,"my"), fitstat(regsize1xft,"my"), fitstat(regsize2xft,"my"), fitstat(regsize3xft,"my")),
  "County FEs & Yes & Yes & Yes & Yes & Yes & Yes  \\\\",
  "Year x State x Small FEs & Yes & No  &  No & Yes & No & No  \\\\",
  "Year x State x Dem vs x Small FEs & No & Yes & No & No & Yes & No  \\\\",
  "Year x State x Pop FEs & No & No & Yes & No & No & Yes  \\\\",
  "County Time Trend & Yes & Yes & Yes & Yes & Yes & Yes \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{7}{p{1\\textwidth}}{\\footnotesize Small counties rank in the bottom half in population compared to other counties within the same state. Robust standard errors clustered by county in parentheses. The number of observations is smaller in columns 3-4 because Arizona and Georgia are excluded and because turnout data is available from 1968 but registration data is only available from 1996.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.10.tex"), sep="\n")


# Table A.11: Presence of a Daily Local Newspaper Attenuates the Effect of Appointing Local Election Officials on Citizen Participation (Even-Year General Elections with County Time Trends, 1968-2022)
regnews1t <- feols(turnout_pc ~ appointed + appointedXnews | year_state_news + fips[year], cluster = "fips_news", data=dat)
regnews2t <- feols(turnout_pc ~ appointed + appointedXnews | year_state_demvs_news + fips[year], cluster = "fips_news", data=dat)
regnews3t <- feols(turnout_pc ~ appointed + appointedXnews | year_state_pop_news + fips[year], cluster = "fips_news", data=dat)
regnews1ft <- feols(reg_pc ~ appointed + appointedXnews | year_state_news + fips[year], cluster = "fips_news", data=filter(dat, reg_separate == 0))
regnews2ft <- feols(reg_pc ~ appointed + appointedXnews | year_state_demvs_news + fips[year], cluster = "fips_news", data=filter(dat, reg_separate == 0))
regnews3ft <- feols(reg_pc ~ appointed + appointedXnews | year_state_pop_news + fips[year], cluster = "fips_news", data=filter(dat, reg_separate == 0))

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Consistent Presence of a Daily Local Newspaper Attenuates the Effect of Appointing Local Election Officials on Citizen Participation (Even-Year General Elections with County Time Trends, 1968-2022)}",
  "\\label{tab:citizen_participation_newstt}}",
  "\\begin{tabular}{lcccccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{3}{c}{Voter Turnout} & \\multicolumn{3}{c}{Registration Rate}\\\\",
  " & (1) & (2) & (3) & (4) & (5) & (6) \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", regnews1t$coefficients[1], regnews2t$coefficients[1], regnews3t$coefficients[1], regnews1ft$coefficients[1], regnews2ft$coefficients[1], regnews3ft$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regnews1t$se[1], regnews2t$se[1], regnews3t$se[1], regnews1ft$se[1], regnews2ft$se[1], regnews3ft$se[1]),
  sprintf("Appointed X Newspaper & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", regnews1t$coefficients[2], regnews2t$coefficients[2], regnews3t$coefficients[2], regnews1ft$coefficients[2], regnews2ft$coefficients[2], regnews3ft$coefficients[2]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regnews1t$se[2], regnews2t$se[2], regnews3t$se[2], regnews1ft$se[2], regnews2ft$se[2], regnews3ft$se[2]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", fitstat(regnews1t,"G"), fitstat(regnews2t,"G"), fitstat(regnews3t,"G"), fitstat(regnews1ft,"G"), fitstat(regnews2ft,"G"), fitstat(regnews3ft,"G")),
  sprintf("Elections & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", 14, 14, 14, 6, 6, 6),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", regnews1t$nobs, regnews2t$nobs, regnews3t$nobs, regnews1ft$nobs, regnews2ft$nobs, regnews3ft$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f \\\\", fitstat(regnews1t,"my"), fitstat(regnews2t,"my"), fitstat(regnews3t,"my"), fitstat(regnews1ft,"my"), fitstat(regnews2ft,"my"), fitstat(regnews3ft,"my")),
  "County FEs & Yes & Yes & Yes & Yes & Yes & Yes \\\\",
  "Year x State x Newspaper FEs & Yes & No & No & Yes & No & No  \\\\",
  "Year x State x Dem vs x Newspaper FEs & No & Yes & No & No & Yes & No \\\\",
  "Year x State x Pop x Newspaper FEs & No & No & Yes & No & No & Yes \\\\",
  "County Time Trend & Yes & Yes & Yes & Yes & Yes & Yes  \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{7}{p{1.05\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses. All counties that switch between having and not having a daily newspaper over the period of analysis are dropped. The number of observations is smaller in columns 4-6 because Arizona and Georgia are excluded and because turnout data is available from 1968 but registration data is only available from 1996.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.11.tex"), sep="\n")


# Table A.12: Effect of Appointing Local Election Officials on Turnover (with County Time Trends, 2004-2022)
## Run lines 315--330 above first

regtempaxt <- feols(turnover2_alt ~ appointed| year_state + fips[year], cluster = "fips",
                    data=filter(dat_turnover, state %in% c("AZ", "CA", "GA", "IL", "IN", "MN", "MO", "MT", "NE", "NV", "OR", "TX", "WA")))

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Effect of Appointing Local Elections Officials on Turnover (with County Time Trends, 2004-2022)}",
  "\\label{tab:turnover_slimtt}}",
  "\\begin{tabular}{lc}",
  "\\toprule \\toprule",
  " & Election Official Turnover \\\\",
  " & (1)   \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f  \\\\", regtempaxt$coefficients[1]),
  sprintf(" & (%1.3f)  \\\\[2mm]", regtempaxt$se[1]),
  "\\midrule",
  sprintf("Counties & %4.0f   \\\\", fitstat(regtempaxt,"G")),
  sprintf("Elections & %4.0f  \\\\", regtempaxt$fixef_sizes[1]/41),
  sprintf("Observations & %4.0f   \\\\", regtempaxt$nobs),
  sprintf("Outcome Mean & %1.2f   \\\\", fitstat(regtempaxt,"my")),
  "County FEs & Yes  \\\\",
  "Year x State FEs & Yes  \\\\",
  "County Time Trend & Yes  \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{2}{p{.5\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.12.tex"), sep="\n")


# Table A.13: Appointing Local Election Officials Increases Voter Turnout in Multiple States (Even-Year General Elections, 1968-2022)
## Calculate how many switches in each state and limit to those with at least 10 switches
num_switchers <- dat %>% 
  group_by(state, fips) %>%
  slice(1) %>% 
  group_by(state) %>% 
  summarise(num_switchers = sum(switcher, na.rm = T))
filter(num_switchers, num_switchers >= 10)

## Run separate regressions for each state
rego1ca <- feols(turnout_pc ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, state == "California"))
rego1ga <- feols(turnout_pc ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, state == "Georgia"))
rego1mn <- feols(turnout_pc ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, state == "Minnesota"))
rego1tx <- feols(turnout_pc ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, state == "Texas"))

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Appointing Local Election Officials Increases Voter Turnout in Multiple States (Even-Year General Elections, 1968-2022)}",
  "\\label{tab:state_turnout}}",
  "\\begin{tabular}{lcccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{4}{c}{Voter Turnout} \\\\",
  " & (1) & (2) & (3) & (4)  \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f \\\\",  rego1ca$coefficients[1], rego1ga$coefficients[1], rego1mn$coefficients[1], rego1tx$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", rego1ca$se[1], rego1ga$se[1], rego1mn$se[1], rego1tx$se[1]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f & %4.0f \\\\", fitstat(rego1ca,"G"), fitstat(rego1ga,"G"), fitstat(rego1mn,"G"), fitstat(rego1tx,"G")),
  sprintf("Elections & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", rego1ca$fixef_sizes[1], rego1ga$fixef_sizes[1], rego1mn$fixef_sizes[1], rego1tx$fixef_sizes[1]),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f \\\\", rego1ca$nobs, rego1ga$nobs, rego1mn$nobs, rego1tx$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f \\\\",  fitstat(rego1ca,"my"), fitstat(rego1ga,"my"), fitstat(rego1mn,"my"), fitstat(rego1tx,"my")),
  "State & CA & GA & MN & TX \\\\",
  "County FEs & Yes & Yes & Yes & Yes \\\\",
  "Year FEs & Yes & Yes & Yes & Yes \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{5}{p{.58\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses. States are included if at least 10 counties have switched between electing and appointing their local election official since 1960.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.13.tex"), sep="\n")


# Table A.14: Switching from Elected Auditors, Clerks, and Probate Judges to Appointed Officials Increases Citizen Participation (Even-Year General Elections, 1968-2022)
rego1officea <- feols(turnout_pc ~ tax_assessor + auditor + clerk + probate_judge  | year_state + fips, cluster = "fips", data=filter(dat, divided_jurisdiction != 1))
rego1officeb <- feols(reg_pc ~ tax_assessor + auditor + clerk + probate_judge | year_state + fips, cluster = "fips", data=filter(dat, divided_jurisdiction != 1))

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Switching from Elected Auditors, Clerks, and Probate Judges to Appointed Officials Increases Citizen Participation (Even-Year General Elections, 1968-2022)}",
  "\\label{tab:leo_office}}",
  "\\begin{tabular}{lcc}",
  "\\toprule \\toprule",
  " & Turnout & Registration  \\\\",
  " & (1) & (2)  \\\\",
  "\\midrule",
  sprintf("Tax Assessor & %1.3f & %1.3f \\\\", -rego1officea$coefficients[1], -rego1officeb$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) \\\\[2mm]", rego1officea$se[1], rego1officeb$se[1]),
  sprintf("Auditor & %1.3f & %1.3f \\\\", -rego1officea$coefficients[2], -rego1officeb$coefficients[2]),
  sprintf(" & (%1.3f) & (%1.3f) \\\\[2mm]", rego1officea$se[2], rego1officeb$se[2]),
  sprintf("Clerk & %1.3f & %1.3f \\\\", -rego1officea$coefficients[3], -rego1officeb$coefficients[3]),
  sprintf(" & (%1.3f) & (%1.3f) \\\\[2mm]", rego1officea$se[3], rego1officeb$se[3]),
  sprintf("Probate Judge & %1.3f & %1.3f \\\\", -rego1officea$coefficients[4], -rego1officeb$coefficients[4]),
  sprintf(" & (%1.3f) & (%1.3f) \\\\[2mm]", rego1officea$se[4], rego1officeb$se[4]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f  \\\\", fitstat(rego1officea,"G"), fitstat(rego1officeb,"G")),
  sprintf("Elections & %4.0f & %4.0f  \\\\", rego1officea$fixef_sizes[1]/13, rego1officeb$fixef_sizes[1]/13),
  sprintf("Observations & %4.0f & %4.0f  \\\\", rego1officea$nobs, rego1officeb$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f  \\\\", fitstat(rego1officea,"my"), fitstat(rego1officeb,"my")),
  "County FEs & Yes & Yes  \\\\",
  "Year x State FEs & Yes & Yes \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{3}{p{.45\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses. Point estimates are reversed for clarity, and thus show the effect of switching from each elected position to an appointed office on participation.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.14.tex"), sep="\n")


# Table A.15: Appointing Local Election Officials Increases Citizen Participation Across Reform Mechanisms
reginitiator1a <- feols(turnout_pc ~ appointed | year_state + fips, cluster = "fips", filter(dat, init_county_leg == 1| switcher == 0))
reginitiator2a <- feols(turnout_pc ~ appointed | year_state + fips, cluster = "fips", data = filter(dat, init_county_ref == 1 |  switcher == 0))
reginitiator3a <- feols(turnout_pc ~ appointed | year_state + fips, cluster = "fips", data = filter(dat, init_state_leg == 1 | switcher == 0))

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Appointing Local Election Officials Increases Citizen Participation Across Reform Mechanisms}",
  "\\label{tab:initiator}}",
  "\\begin{tabular}{lccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{3}{c}{Voter Turnout} \\\\",
  " & (1) & (2) & (3)  \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f  \\\\", reginitiator1a$coefficients[1], reginitiator2a$coefficients[1], reginitiator3a$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f)  \\\\[2mm]", reginitiator1a$se[1], reginitiator2a$se[1], reginitiator3a$se[1]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f \\\\", fitstat(reginitiator1a,"G"), fitstat(reginitiator2a,"G"), fitstat(reginitiator3a,"G")),
  sprintf("Elections & %4.0f & %4.0f & %4.0f   \\\\", reginitiator1a$fixef_sizes[1]/13, reginitiator2a$fixef_sizes[1]/13, reginitiator3a$fixef_sizes[1]/13),
  sprintf("Observations & %4.0f & %4.0f & %4.0f \\\\", reginitiator1a$nobs, reginitiator2a$nobs, reginitiator3a$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f  \\\\", fitstat(reginitiator1a,"my"), fitstat(reginitiator2a,"my"), fitstat(reginitiator3a,"my")),
  "Initiator & County Leg & County Referendum & State Leg \\\\",
  "County FEs & Yes & Yes & Yes  \\\\",
  "Year x State FEs & Yes & Yes & Yes  \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{4}{p{.7\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.15.tex"), sep="\n")


# Table A.16: Finding that Appointing Local Election Officials Increases Citizen Participation is Robust to Removing County Charter Changes
regpackage1a <- feols(turnout_pc ~ appointed | year_state + fips, cluster = "fips", data = filter(dat, package_reform_binary == 0 | switcher == 0))
regpackage1b <- feols(turnout_pc ~ appointed | year_state_demvs + fips, cluster = "fips", data = filter(dat, package_reform_binary == 0 | switcher == 0))
regpackage1c <- feols(turnout_pc ~ appointed | year_state_pop + fips, cluster = "fips", data = filter(dat, package_reform_binary == 0 | switcher == 0))
regpackage2a <- feols(reg_pc ~ appointed | year_state + fips, cluster = "fips", data = filter(dat, reg_separate == 0 & (package_reform_binary == 0 | switcher == 0)))
regpackage2b <- feols(reg_pc ~ appointed | year_state_demvs + fips, cluster = "fips", data = filter(dat, reg_separate == 0 & (package_reform_binary == 0 | switcher == 0)))
regpackage2c <- feols(reg_pc ~ appointed | year_state_pop + fips, cluster = "fips", data = filter(dat, reg_separate == 0 & (package_reform_binary == 0 | switcher == 0)))

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Finding that Appointing Local Election Officials Increases Citizen Participation is Robust to Removing County Charter Changes}",
  "\\label{tab:county_charters}}",
  "\\begin{tabular}{lcccccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{3}{c}{Voter Turnout} & \\multicolumn{3}{c}{Registration Rate}\\\\",
  " & (1) & (2) & (3) & (4) & (5) & (6) \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", regpackage1a$coefficients[1], regpackage1b$coefficients[1], regpackage1c$coefficients[1], regpackage2a$coefficients[1], regpackage2b$coefficients[1], regpackage2c$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regpackage1a$se[1], regpackage1b$se[1], regpackage1c$se[1], regpackage2a$se[1], regpackage2b$se[1], regpackage2c$se[1]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", fitstat(regpackage1a,"G"), fitstat(regpackage1b,"G"), fitstat(regpackage1c,"G"), fitstat(regpackage2a,"G"), fitstat(regpackage2b,"G"), fitstat(regpackage2c,"G")),
  sprintf("Elections & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", regpackage1a$fixef_sizes[1]/13, regpackage1b$fixef_sizes[1]/52, regpackage1c$fixef_sizes[1]/52, regpackage2a$fixef_sizes[1]/12, regpackage2b$fixef_sizes[1]/48, regpackage2c$fixef_sizes[1]/48),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", regpackage1a$nobs, regpackage1b$nobs, regpackage1c$nobs, regpackage2a$nobs, regpackage2b$nobs, regpackage2c$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f \\\\", fitstat(regpackage1a,"my"), fitstat(regpackage1b,"my"), fitstat(regpackage1c,"my"), fitstat(regpackage2a,"my"), fitstat(regpackage2b,"my"), fitstat(regpackage2c,"my")),
  "County FEs & Yes & Yes & Yes & Yes & Yes & Yes \\\\",
  "Year x State FEs & Yes & No & No & Yes & No & No  \\\\",
  "Year x State x Dem vote share FEs & No & Yes & No & No & Yes & No \\\\",
  "Year x State x Population FEs & No & No & Yes & No & No & Yes \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{7}{p{1\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses. Voter turnout and registration rate are measured as proportions out of 1. Counties that switched the selection method of clerk as part of a package of reforms to their county charter are removed.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.16.tex"), sep="\n")


# Table A.17: Finding that Appointing Local Election Officials Increases Citizen Participation is Robust to Alternative Year Cutoffs
regt1980f <- feols(turnout_pc ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, year >= 1980))
regt1990f <- feols(turnout_pc ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, year >= 1990))
regt2000f <- feols(turnout_pc ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, year >= 2000))
regt2010f <- feols(turnout_pc ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, year >= 2010))

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Finding that Appointing Local Election Officials Increases Citizen Participation is Robust to Alternative Year Cutoffs}",
  "\\label{tab:citizen_participation_years_small}}",
  "\\begin{tabular}{lcccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{4}{c}{Voter Turnout} \\\\",
  " & (1) & (2) & (3) & (4)  \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", regt1980f$coefficients[1], regt1990f$coefficients[1], regt2000f$coefficients[1], regt2010f$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f)  \\\\[2mm]", regt1980f$se[1], regt1990f$se[1], regt2000f$se[1], regt2010f$se[1]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f & %4.0f \\\\", fitstat(regt1980f,"G"), fitstat(regt1990f,"G"), fitstat(regt2000f,"G"), fitstat(regt2010f,"G")),
  sprintf("Elections & %4.0f & %4.0f & %4.0f & %4.0f   \\\\", regt1980f$fixef_sizes[1]/26, regt1990f$fixef_sizes[1]/26, regt2000f$fixef_sizes[1]/26, regt2010f$fixef_sizes[1]/26),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f \\\\", regt1980f$nobs, regt1990f$nobs, regt2000f$nobs, regt2010f$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f  \\\\", fitstat(regt1980f,"my"), fitstat(regt1990f,"my"), fitstat(regt2000f,"my"), fitstat(regt2010f,"my")),
  "Year Cutoff & 1980 & 1990 & 2000 & 2010 \\\\",
  "County FEs & Yes & Yes & Yes & Yes \\\\",
  "Year x State FEs & Yes & Yes & Yes & Yes  \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{5}{p{.6\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses. Year cutoff indicates the first even-year general election included in the analysis.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.17.tex"), sep="\n")


# Table A.18: Finding that Appointing Local Election Officials Increases Citizen Participation is Robust to Alternative Estimators (Even-Year General Elections, 1968-2022)
## Set up clean panel dataset
dat1 <- dat %>% 
  select(state, county, fips, statecounty, year_state, year, turnout_pc, reg_pc, log_expnd_per_reg, appointed, appoint_to_elect, always_appointed, always_elected) %>% 
  filter(year >1967) %>% 
  #        state != "Texas" | county != "Dewitt") %>% 
  group_by(state) %>% 
  mutate(state_id = cur_group_id()) %>% 
  group_by(fips) %>% 
  mutate(county_id = cur_group_id()) %>% 
  ungroup()
tmp <- dat1 %>% 
  mutate(year = as.numeric(year)) %>% 
  group_by(fips) %>% 
  arrange(fips, year) %>% 
  mutate(appoint_year = ifelse(appointed == 1, year, max(year)+2)) %>% 
  slice(which.min(appoint_year)) %>% 
  select (fips, appoint_year) %>% 
  mutate(appoint_year = if_else(appoint_year ==2024, 0, appoint_year))

dat1 <- left_join(dat1, tmp, by = "fips") 

## Set up stacked panel dataset
dat2 <- dat1 %>% 
  filter(appoint_to_elect==0 &  always_appointed != 1) # filter out switchers and always treated

dat2a <- dat2 %>%  filter(always_elected!=1)
dat2b <- dat2 %>%  filter(always_elected==1) %>%  # true controls
  as.data.frame(lapply(rep=26))

expand_r <- function(df, ...) {
  as.data.frame(lapply(df, rep, ...))
}

dat2b <- expand_r(dat2b, times = 27)

dat2 <- rbind(dat2a, dat2b) %>% 
  arrange(state, county, year) %>%
  group_by(state, statecounty, year) %>% 
  mutate(appoint_year = ifelse(appoint_year == 0, row_number()*2 + 1968, appoint_year)) %>% 
  ungroup() %>% 
  mutate(year_state_appoint_year = paste0(year_state, appoint_year),
         year_appoint_year = paste0(year, appoint_year),
         years_since = year - appoint_year) %>% 
  group_by(state, county, appoint_year) %>% 
  mutate(min_years_since = min(years_since),
         max_years_since = max(years_since))

## Run alternative specifications
regtest <- feols(turnout_pc ~ appointed | county_id + year_state, cluster = "county_id", data=dat1)
regtest1 <- feols(turnout_pc ~ appointed | county_id + year_state, cluster = "county_id",
                  data=filter(dat1, appoint_to_elect==0)) # excluding appoint_to_elect
regtest2 <- feols(turnout_pc ~ appointed | county_id + year_state, cluster = "county_id",
                  data=filter(dat1, appoint_to_elect==0 & always_appointed != 1)) # excluding appoint_to_elect and always treated
regstack1 <- feols(turnout_pc ~ appointed | county_id + year_state_appoint_year, cluster = "county_id", data=dat2)
regstack5 <- feols(turnout_pc ~ appointed | county_id + year_state_appoint_year, cluster = "county_id",
                   data=filter(dat2, years_since >=-8 & years_since <= 16 & max_years_since >= 16 & min_years_since <=-8))

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Finding that Appointing Local Election Officials Increases Citizen Participation Is Robust to Alternative Estimators (Even-Year General Elections, 1968-2020)}",
  "\\label{tab:robust_handrolled}}",
  "\\begin{tabular}{lccccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{5}{c}{Voter Turnout} \\\\",
  " & (1) & (2) & (3) & (4) & (5)  \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", regtest$coefficients[1], regtest1$coefficients[1], regtest2$coefficients[1], regstack1$coefficients[1], regstack5$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regtest$se[1], regtest1$se[1], regtest2$se[1], regstack1$se[1], regstack5$se[1]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", fitstat(regtest,"G"), fitstat(regtest1,"G"), fitstat(regtest2,"G"), fitstat(regstack1,"G"), fitstat(regstack5,"G")),
  sprintf("Elections (avg) & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f   \\\\", regtest$fixef_sizes[2]/13, regtest1$fixef_sizes[2]/13, regtest2$fixef_sizes[2]/13, 28, 28),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", regtest$nobs, regtest1$nobs, regtest2$nobs, regstack1$nobs, regstack5$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f \\\\", fitstat(regtest,"my"), fitstat(regtest1,"my"), fitstat(regtest2,"my"), fitstat(regstack1,"my"), fitstat(regstack5,"my")),
  "County FEs & Yes & Yes & Yes & Yes & Yes  \\\\",
  "Year x State FEs & Yes & Yes & Yes & Yes & Yes  \\\\",
  "App to Elect Excluded & No & Yes & Yes & Yes & Yes  \\\\",
  "Always Treated Excluded & No & No & Yes & Yes & Yes  \\\\",
  "Stacked DiD & No & No & No & Yes & Yes  \\\\",
  "Shortened Event Window & No & No & No & No & Yes  \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{6}{p{.8\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses. Column 1 is identical to the specification shown in column 1 of Table 1. Column 2 excludes 28 counties that switch from appointing to electing their clerks. Column 3 additionally excludes counties that have not elected their clerk since 1966. Column 4 implements a stacked difference-in-difference regression following the procedure described by Cengiz et al. 2019.  Column 5 additionally shortens the event window for each county to within 8 years before its switch and within 16 years after its switch.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.18.tex"), sep="\n")


# Table A.19: Finding that Appointing Local Election Officials Increases Voter Turnout Is Robust to Imai et al. 2024 Matching Estimator (Even-Year General Elections, 1968-2022)
set.seed(123)

dat_pm <- dat %>% 
  mutate(year_id = (year - 1960)/2,
         state_demvs = paste0(state, dem_vs_quart),
         state_pop = paste0(state, pop_quart))
dat_pm <- as.data.frame(dat_pm)

matches <- PanelMatch(
  lag = 8, # can vary
  time.id = "year_id",
  unit.id = "fips",
  treatment = "appointed",
  outcome.var = "turnout_pc",
  refinement.method = "mahalanobis",
  data = dat_pm,
  qoi = "att",
  size.match = 10, 
  match.missing = FALSE,
  covs.formula = ~ turnout_pc + state,
  lead = 8, # can vary
  exact.match.variables = "state",
  forbid.treatment.reversal = TRUE,
  use.diagonal.variance.matrix = TRUE,
  restrict.control.period = 4)

imai_est <- PanelEstimate(
  sets = matches,
  data = dat_pm,
  number.iterations = 1000,
  df.adjustment = TRUE,
  confidence.level = .95,
  se.method = "bootstrap",
  pooled = TRUE,
  parallel = TRUE,
  num.cores = 4)

matchesa <- PanelMatch(lag = 8, time.id = "year_id", unit.id = "fips", treatment = "appointed",  outcome.var = "turnout_pc",
                       refinement.method = "mahalanobis", data = dat_pm, qoi = "att", match.missing = FALSE, covs.formula = ~ turnout_pc + state_demvs,
                       lead = 8, exact.match.variables = "state_demvs", forbid.treatment.reversal = TRUE, use.diagonal.variance.matrix = TRUE, restrict.control.period = 4)
imai_esta <- PanelEstimate(sets = matchesa, data = dat_pm, df.adjustment = TRUE, se.method = "bootstrap", pooled = TRUE, parallel = TRUE, num.cores = 4)

matchesb <- PanelMatch(lag = 8, time.id = "year_id", unit.id = "fips", treatment = "appointed",  outcome.var = "turnout_pc",
                       refinement.method = "mahalanobis", data = dat_pm, qoi = "att", match.missing = FALSE, covs.formula = ~ turnout_pc + state_pop,
                       lead = 8, exact.match.variables = "state_pop", forbid.treatment.reversal = TRUE, use.diagonal.variance.matrix = TRUE, restrict.control.period = 4)
imai_estb <- PanelEstimate(sets = matchesb, data = dat_pm, df.adjustment = TRUE, se.method = "bootstrap", pooled = TRUE, parallel = TRUE, num.cores = 4)

imai_coef <- imai_est$estimates
imai_se <- imai_est$standard.error
imai_match_number <-length(imai_est$matched.sets)

imai_coefa <- imai_esta$estimates
imai_sea <- imai_esta$standard.error
imai_match_numbera <-length(imai_esta$matched.sets)

imai_coefb <- imai_estb$estimates
imai_seb <- imai_estb$standard.error
imai_match_numberb <-length(imai_estb$matched.sets)

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Finding that Appointing Local Election Officials Increases Voter Turnout Is Robust to Imai et al. 2024 Matching Estimator (Even-Year General Elections, 1968-2020)}",
  "\\label{tab:robust_handrolled_Imai}}",
  "\\begin{tabular}{lccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{3}{c}{Voter Turnout} \\\\",
  " & (1) & (2) & (3) \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f  \\\\", imai_coef,imai_coefa, imai_coefb),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f)  \\\\[2mm]", imai_se, imai_sea, imai_seb),
  "\\midrule",
  sprintf("Matches & %4.0f & %4.0f & %4.0f \\\\", imai_match_number, imai_match_numbera, imai_match_numberb),
  "County FEs & Yes & Yes & Yes  \\\\",
  "Year FEs & Yes & Yes & Yes  \\\\",
  "Pre-treatment voter turnout matching & Yes & Yes & Yes   \\\\",
  "State exact matching & Yes & No & No   \\\\",
  "State x Dem vote share exact matching & No & Yes & No \\\\",
  "State x Population exact matching & No & No & Yes \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{4}{p{.75\\textwidth}}{\\footnotesize Bootstrapped standard errors with a degree-of-freedom adjustment in parentheses. All regressions use a pooled estimator that averages over the first 8 elections after treatment and matches over 8 elections prior to treatment. Matching is done using mahalanobis distance}", 
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.19.tex"), sep="\n")


# Table A.20: Finding that Appointing Local Election Officials Increases Voter Registration Is Robust to Imai et al. 2024 Matching Estimator (Even-Year General Elections, 1968-2022)
set.seed(123)

dat_pm <- dat %>% 
  filter(!is.na(reg_pc)) %>% 
  mutate(year_id = (year - 1996)/2,
         state_demvs = paste0(state, dem_vs_quart),
         state_pop = paste0(state, pop_quart))
dat_pm <- as.data.frame(dat_pm)

matches <- PanelMatch(
  lag = 4, # can vary
  time.id = "year_id",
  unit.id = "fips",
  treatment = "appointed",
  outcome.var = "reg_pc",
  refinement.method = "mahalanobis",
  data = dat_pm,
  qoi = "att",
  size.match = 10, 
  match.missing = FALSE,
  covs.formula = ~ reg_pc + state,
  lead = 4, # can vary
  exact.match.variables = "state",
  forbid.treatment.reversal = TRUE,
  use.diagonal.variance.matrix = TRUE,
  restrict.control.period = 4)

imai_est <- PanelEstimate(
  sets = matches,
  data = dat_pm,
  number.iterations = 1000,
  df.adjustment = TRUE,
  confidence.level = .95,
  se.method = "bootstrap",
  pooled = TRUE,
  parallel = TRUE,
  num.cores = 4)

matchesa <- PanelMatch(lag = 4, time.id = "year_id", unit.id = "fips", treatment = "appointed",  outcome.var = "reg_pc",
                       refinement.method = "mahalanobis", data = dat_pm, qoi = "att", match.missing = FALSE, covs.formula = ~ reg_pc + state_demvs,
                       lead = 4, exact.match.variables = "state_demvs", forbid.treatment.reversal = TRUE, use.diagonal.variance.matrix = TRUE, restrict.control.period = 4)
imai_esta <- PanelEstimate(sets = matchesa, data = dat_pm, df.adjustment = TRUE, se.method = "bootstrap", pooled = TRUE, parallel = TRUE, num.cores = 4)

matchesb <- PanelMatch(lag = 4, time.id = "year_id", unit.id = "fips", treatment = "appointed",  outcome.var = "reg_pc",
                       refinement.method = "mahalanobis", data = dat_pm, qoi = "att", match.missing = FALSE, covs.formula = ~ reg_pc + state_pop,
                       lead = 4, exact.match.variables = "state_pop", forbid.treatment.reversal = TRUE, use.diagonal.variance.matrix = TRUE, restrict.control.period = 4)
imai_estb <- PanelEstimate(sets = matchesb, data = dat_pm, df.adjustment = TRUE, se.method = "bootstrap", pooled = TRUE, parallel = TRUE, num.cores = 4)

imai_coef_reg <- imai_est$estimates
imai_se_reg <- imai_est$standard.error
imai_match_number_reg <-length(imai_est$matched.sets)

imai_coefa_reg <- imai_esta$estimates
imai_sea_reg <- imai_esta$standard.error
imai_match_numbera_reg <-length(imai_esta$matched.sets)

imai_coefb_reg <- imai_estb$estimates
imai_seb_reg <- imai_estb$standard.error
imai_match_numberb_reg <-length(imai_estb$matched.sets)

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Finding that Appointing Local Election Officials Increases Voter Registration Is Robust to Imai et al. 2024 Matching Estimator (Even-Year General Elections, 1996-2020)}",
  "\\label{tab:robust_handrolled_Imai_reg}}",
  "\\begin{tabular}{lccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{3}{c}{Registration Rate} \\\\",
  " & (1) & (2) & (3) \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f  \\\\", imai_coef_reg,imai_coefa_reg, imai_coefb_reg),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f)  \\\\[2mm]", imai_se_reg, imai_sea_reg, imai_seb_reg),
  "\\midrule",
  sprintf("Matches & %4.0f & %4.0f & %4.0f \\\\", imai_match_number_reg, imai_match_numbera_reg, imai_match_numberb_reg),
  "County FEs & Yes & Yes & Yes  \\\\",
  "Year FEs & Yes & Yes & Yes  \\\\",
  "Pre-treatment voter turnout matching & Yes & Yes & Yes   \\\\",
  "State exact matching & Yes & No & No   \\\\",
  "State x Dem vote share exact matching & No & Yes & No \\\\",
  "State x Population exact matching & No & No & Yes \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{4}{p{.75\\textwidth}}{\\footnotesize Bootstrapped standard errors with a degree-of-freedom adjustment in parentheses. All regressions use a pooled estimator that averages over the first 4 elections after treatment and matches over 4 elections prior to treatment. Matching is done using mahalanobis distance}", 
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.20.tex"), sep="\n")


# Table A.21: Effect of Appointing Local Election Officials on Election Expenditures using Imai et al. 2024 Matching Estimator (Even-Year General Elections, 2002-2022)
set.seed(123)

dat_pm_budget <- dat %>% 
  filter(!is.na(log_expnd_per_reg)) %>% 
  mutate(year_id = (year - 2000)/2,
         state_demvs = paste0(state, dem_vs_quart),
         state_pop = paste0(state, pop_quart))
dat_pm_budget <- as.data.frame(dat_pm_budget)

matches <- PanelMatch(
  lag = 2, # can vary
  time.id = "year_id",
  unit.id = "fips",
  treatment = "appointed",
  outcome.var = "log_expnd_per_reg",
  refinement.method = "mahalanobis",
  data = dat_pm_budget,
  qoi = "att",
  size.match = 10, 
  match.missing = FALSE,
  covs.formula = ~ log_expnd_per_reg + state,
  lead = 2, # can vary
  exact.match.variables = "state",
  forbid.treatment.reversal = TRUE,
  use.diagonal.variance.matrix = TRUE,
  restrict.control.period = 2)
set.seed(123)
imai_est_budget <- PanelEstimate(
  sets = matches,
  data = dat_pm_budget,
  number.iterations = 1000,
  df.adjustment = TRUE,
  confidence.level = .95,
  se.method = "bootstrap",
  pooled = TRUE,
  parallel = FALSE,
  num.cores = 4)

matchesa <- PanelMatch(lag = 2, time.id = "year_id", unit.id = "fips", treatment = "appointed",  outcome.var = "log_expnd_per_reg",
                       refinement.method = "mahalanobis", data = dat_pm_budget, qoi = "att", match.missing = FALSE, covs.formula = ~ log_expnd_per_reg + state_demvs,
                       lead = 2, exact.match.variables = "state_demvs", forbid.treatment.reversal = TRUE, use.diagonal.variance.matrix = TRUE, restrict.control.period = 2)
set.seed(123)
imai_esta <- PanelEstimate(sets = matchesa, data = dat_pm_budget, df.adjustment = TRUE, se.method = "bootstrap", pooled = TRUE, parallel = FALSE, num.cores = 2)

matchesb <- PanelMatch(lag = 2, time.id = "year_id", unit.id = "fips", treatment = "appointed",  outcome.var = "log_expnd_per_reg",
                       refinement.method = "mahalanobis", data = dat_pm_budget, qoi = "att", match.missing = FALSE, covs.formula = ~ log_expnd_per_reg + state_pop,
                       lead = 2, exact.match.variables = "state_pop", forbid.treatment.reversal = TRUE, use.diagonal.variance.matrix = TRUE, restrict.control.period = 2)
set.seed(123)
imai_estb <- PanelEstimate(sets = matchesb, data = dat_pm_budget, df.adjustment = TRUE, se.method = "bootstrap", pooled = TRUE, parallel = FALSE, num.cores = 2)

imai_coef_budget <- imai_est_budget$estimates
imai_se_budget <- imai_est_budget$standard.error
imai_match_number_budget <-length(imai_est_budget$matched.sets)

imai_coefa_budget <- imai_esta$estimates
imai_sea_budget <- imai_esta$standard.error
imai_match_numbera_budget <-length(imai_esta$matched.sets)

imai_coefb_budget <- imai_estb$estimates
imai_seb_budget <- imai_estb$standard.error
imai_match_numberb_budget <-length(imai_estb$matched.sets)

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Effect of Appointing Local Election Officials on Election Expenditures using Imai et al. 2024 Matching Estimator (Even-Year General Elections, 2002-2020)}",
  "\\label{tab:robust_handrolled_Imai_budget}}",
  "\\begin{tabular}{lccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{3}{c}{Ln expend per reg} \\\\",
  " & (1) & (2) & (3) \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f  \\\\", imai_coef_budget,imai_coefa_budget, imai_coefb_budget),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f)  \\\\[2mm]", imai_se_budget, imai_sea_budget, imai_seb_budget),
  "\\midrule",
  sprintf("Matches & %4.0f & %4.0f & %4.0f \\\\", imai_match_number_budget, imai_match_numbera_budget, imai_match_numberb_budget),
  "County FEs & Yes & Yes & Yes  \\\\",
  "Year FEs & Yes & Yes & Yes  \\\\",
  "Pre-treatment election expenditure matching & Yes & Yes & Yes   \\\\",
  "State exact matching & Yes & No & No   \\\\",
  "State x Dem vote share exact matching & No & Yes & No \\\\",
  "State x Population exact matching & No & No & Yes \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{4}{p{.75\\textwidth}}{\\footnotesize Bootstrapped standard errors with a degree-of-freedom adjustment in parentheses. All regressions use a pooled estimator that averages over the first 2 elections after treatment and matches over 2 elections prior to treatment. Matching is done using mahalanobis distance}", 
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.21.tex"), sep="\n")


# Table A.22: Main Finding that Appointing Local Election Officials Increases Voter Turnout is Robust to Alternate Specifications - California
set.seed(1234)

rego1ca <- feols(turnout_pc ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, state == "California"))
bca <- did_multiplegt(mode = "dyn", df = filter(dat, state == "California"), outcome = "turnout_pc", group = "fips", time = "year", treatment = "appointed", placebo = 3,
                      cluster = "fips", effects = 5)
Callawayca <- att_gt(yname = "turnout_pc",
                     tname = "year",
                     idname = "fips",
                     gname = "cohort",
                     data = filter(dat, always_appointed == 0 & multiple_switches != 1 & appoint_to_elect != 1 & ever_divided != 1 & state == "California"),
                     allow_unbalanced_panel = TRUE,
                     control_group = "nevertreated",
                     bstrap = TRUE,
                     cband = TRUE,
                     biters = 1000,
                     clustervars = "fips",
                     est_method = "dr",
                     base_period = "varying")
Callaway_dynamic_ca <- aggte(Callawayca, type = "dynamic")
ggdid(Callaway_dynamic_ca,
      xlab = "Years of Exposure to Appointing Election Official",
      ylab = "Effect on Voter Turnout",
      title = " ",
      xgap = 2)
Callaway_dynamic_ca$N <- nrow(dat %>% group_by(fips) %>%  filter(any(elected != 0)) %>%  ungroup() %>% filter(state == "California"))

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Main Finding that Appointing Local Election Officials Increases Voter Turnout is Robust to Alternate Specifications - California}",
  "\\label{tab:validation_ca}}",
  "\\begin{tabular}{lccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{3}{c}{Voter Turnout} \\\\",
  " & Two-Way & de Chaisemartin and & Callaway and  \\\\",
  " & FEs & D'Haultfoeuille & Sant'Anna   \\\\",
  " & (1) & (2) & (3)  \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f  \\\\", rego1ca$coefficients[1], bca$results[[4]][1], Callaway_dynamic_ca$overall.att),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f)  \\\\[2mm]", rego1ca$se[1], bca$results[[4]][2], Callaway_dynamic_ca$overall.se),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f  \\\\", fitstat(rego1ca,"G"), fitstat(rego1ca,"G"), Callaway_dynamic_ca[["DIDparams"]][["n"]]),
  sprintf("Elections & %4.0f & %4.0f & %4.0f  \\\\", rego1ca$fixef_sizes[1], 28, Callaway_dynamic_ca[["DIDparams"]][["nT"]]),
  sprintf("Observations & %4.0f & %4.0f & %4.0f  \\\\", rego1ca$nobs, bca$results[[4]][5], Callaway_dynamic_ca$N),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f  \\\\", fitstat(rego1ca,"my"), fitstat(rego1ca,"my"), fitstat(rego1ca,"my")),
  "County FEs & Yes & Yes & Yes  \\\\",
  "Year FEs & Yes & Yes & Yes  \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{4}{p{.6\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.22.tex"), sep="\n")


# Table A.23: Main Finding that Appointing Local Election Officials Increases Voter Turnout is Robust to Alternate Specifications - Georgia
set.seed(1234)

rego1ga <- feols(turnout_pc ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, state == "Georgia"))
bga <- did_multiplegt(mode = "dyn", df = filter(dat, state == "Georgia"), outcome = "turnout_pc", group = "fips", time = "year", treatment = "appointed", placebo = 3,
                      cluster = "fips", effects = 5)
Callawayga <- att_gt(yname = "turnout_pc",
                     tname = "year",
                     idname = "fips",
                     gname = "cohort",
                     data = filter(dat, always_appointed == 0 & multiple_switches != 1 & appoint_to_elect != 1 & ever_divided != 1 & state == "Georgia"),
                     allow_unbalanced_panel = TRUE,
                     control_group = "nevertreated",
                     bstrap = TRUE,
                     cband = TRUE,
                     biters = 1000,
                     clustervars = "fips",
                     est_method = "dr",
                     base_period = "varying")
Callaway_dynamic_ga <- aggte(Callawayga, type = "dynamic")
ggdid(Callaway_dynamic_ga,
      xlab = "Years of Exposure to Appointing Election Official",
      ylab = "Effect on Voter Turnout",
      title = " ",
      xgap = 2)
Callaway_dynamic_ga$N <- nrow(dat %>% group_by(fips) %>%  filter(any(elected != 0)) %>%  ungroup() %>% filter(state == "Georgia"))

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Main Finding that Appointing Local Election Officials Increases Voter Turnout is Robust to Alternate Specifications - Georgia}",
  "\\label{tab:validation_ga}}",
  "\\begin{tabular}{lccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{3}{c}{Voter Turnout} \\\\",
  " & Two-Way & de Chaisemartin and & Callaway and  \\\\",
  " & FEs & D'Haultfoeuille & Sant'Anna   \\\\",
  " & (1) & (2) & (3)  \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f  \\\\", rego1ga$coefficients[1], bga$results[[4]][1], Callaway_dynamic_ga$overall.att),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f)  \\\\[2mm]", rego1ga$se[1], bga$results[[4]][2], Callaway_dynamic_ga$overall.se),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f  \\\\", fitstat(rego1ga,"G"), fitstat(rego1ga,"G"), Callaway_dynamic_ga[["DIDparams"]][["n"]]),
  sprintf("Elections & %4.0f & %4.0f & %4.0f  \\\\", rego1ga$fixef_sizes[1], 28, Callaway_dynamic_ga[["DIDparams"]][["nT"]]),
  sprintf("Observations & %4.0f & %4.0f & %4.0f  \\\\", rego1ga$nobs, bga$results[[4]][5], Callaway_dynamic_ga$N),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f  \\\\", fitstat(rego1ga,"my"), fitstat(rego1ga,"my"), fitstat(rego1ga,"my")),
  "County FEs & Yes & Yes & Yes  \\\\",
  "Year FEs & Yes & Yes & Yes  \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{4}{p{.6\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.23.tex"), sep="\n")


# Table A.24: Main Finding that Appointing Local Election Officials Increases Voter Turnout is Robust to Alternate Specifications - Minnesota
set.seed(1234)

rego1mn <- feols(turnout_pc ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, state == "Minnesota"))
bmn <- did_multiplegt(mode = "dyn", df = filter(dat, state == "Minnesota"), outcome = "turnout_pc", group = "fips", time = "year", treatment = "appointed", placebo = 3,
                      cluster = "fips", effects = 5)
Callawaymn <- att_gt(yname = "turnout_pc",
                     tname = "year",
                     idname = "fips",
                     gname = "cohort",
                     data = filter(dat, always_appointed == 0 & multiple_switches != 1 & appoint_to_elect != 1 & ever_divided != 1 & state == "Minnesota"),
                     allow_unbalanced_panel = TRUE,
                     control_group = "nevertreated",
                     bstrap = TRUE,
                     cband = TRUE,
                     biters = 1000,
                     clustervars = "fips",
                     est_method = "dr",
                     base_period = "varying")
Callaway_dynamic_mn <- aggte(Callawaymn, type = "dynamic")
ggdid(Callaway_dynamic_mn,
      xlab = "Years of Exposure to Appointing Election Official",
      ylab = "Effect on Voter Turnout",
      title = " ",
      xgap = 2)
ggdid(Callaway_dynamic_mn,
      xlab = "Years of Exposure to Appointing Election Official",
      ylab = "Effect on Voter Turnout",
      title = " ",
      xgap = 2)
Callaway_dynamic_mn$N <- nrow(dat %>% group_by(fips) %>%  filter(any(elected != 0)) %>%  ungroup() %>% filter(state == "Minnesota"))

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Main Finding that Appointing Local Election Officials Increases Voter Turnout is Robust to Alternate Specifications - Minnesota}",
  "\\label{tab:validation_mn}}",
  "\\begin{tabular}{lccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{3}{c}{Voter Turnout} \\\\ ",
  " & Two-Way & de Chaisemartin and & Callaway and  \\\\",
  " & FEs & D'Haultfoeuille & Sant'Anna   \\\\",
  " & (1) & (2) & (3)  \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f  \\\\", rego1mn$coefficients[1], bmn$results[[4]][1], Callaway_dynamic_mn$overall.att),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f)  \\\\[2mm]", rego1mn$se[1], bmn$results[[4]][2], Callaway_dynamic_mn$overall.se),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f  \\\\", fitstat(rego1mn,"G"), fitstat(rego1mn,"G"), Callaway_dynamic_mn[["DIDparams"]][["n"]]),
  sprintf("Elections & %4.0f & %4.0f & %4.0f  \\\\", rego1mn$fixef_sizes[1], 28, Callaway_dynamic_mn[["DIDparams"]][["nT"]]),
  sprintf("Observations & %4.0f & %4.0f & %4.0f  \\\\", rego1mn$nobs, bmn$results[[4]][5], Callaway_dynamic_mn$N),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f  \\\\", fitstat(rego1mn,"my"), fitstat(rego1mn,"my"), fitstat(rego1mn,"my")),
  "County FEs & Yes & Yes & Yes  \\\\",
  "Year FEs & Yes & Yes & Yes  \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{4}{p{.6\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.24.tex"), sep="\n")


# Table A.25: Main Finding that Appointing Local Election Officials Increases Voter Turnout is Robust to Alternate Specifications - Texas
set.seed(1234)

rego1tx <- feols(turnout_pc ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, state == "Texas"))
btx <- did_multiplegt(mode = "dyn", df = filter(dat, state == "Texas"), outcome = "turnout_pc", group = "fips", time = "year", treatment = "appointed", placebo = 3,
                      cluster = "fips", effects = 5)
Callawaytx <- att_gt(yname = "turnout_pc",
                     tname = "year",
                     idname = "fips",
                     gname = "cohort",
                     data = filter(dat, always_appointed == 0 & multiple_switches != 1 & appoint_to_elect != 1 & ever_divided != 1 & state == "Texas"),
                     allow_unbalanced_panel = TRUE,
                     control_group = "nevertreated",
                     bstrap = TRUE,
                     cband = TRUE,
                     biters = 1000,
                     clustervars = "fips",
                     est_method = "dr",
                     base_period = "varying")
Callaway_dynamic_tx <- aggte(Callawaytx, type = "dynamic")
ggdid(Callaway_dynamic_tx,
      xlab = "Years of Exposure to Appointing Election Official",
      ylab = "Effect on Voter Turnout",
      title = " ",
      xgap = 2)
Callaway_dynamic_tx$N <- nrow(dat %>% group_by(fips) %>%  filter(any(elected != 0)) %>%  ungroup() %>% filter(state == "Texas"))

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Main Finding that Appointing Local Election Officials Increases Voter Turnout is Robust to Alternate Specifications - Texas}",
  "\\label{tab:validation_tx}}",
  "\\begin{tabular}{lccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{3}{c}{Voter Turnout} \\\\",
  " & Two-Way & de Chaisemartin and & Callaway and  \\\\",
  " & FEs & D'Haultfoeuille & Sant'Anna   \\\\",
  " & (1) & (2) & (3)  \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f  \\\\", rego1tx$coefficients[1], btx$results[[4]][1], Callaway_dynamic_tx$overall.att),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f)  \\\\[2mm]", rego1tx$se[1], btx$results[[4]][2], Callaway_dynamic_tx$overall.se),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f  \\\\", fitstat(rego1tx,"G"), fitstat(rego1tx,"G"), Callaway_dynamic_tx[["DIDparams"]][["n"]]),
  sprintf("Elections & %4.0f & %4.0f & %4.0f  \\\\", rego1tx$fixef_sizes[1], 28, Callaway_dynamic_tx[["DIDparams"]][["nT"]]),
  sprintf("Observations & %4.0f & %4.0f & %4.0f  \\\\", rego1tx$nobs, btx$results[[4]][5], Callaway_dynamic_tx$N),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f  \\\\", fitstat(rego1tx,"my"), fitstat(rego1tx,"my"), fitstat(rego1tx,"my")),
  "County FEs & Yes & Yes & Yes  \\\\",
  "Year FEs & Yes & Yes & Yes  \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{4}{p{.6\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.25.tex"), sep="\n")


# Table A.26: Main Finding that Appointing Local Election Officials Increases Voter Turnout is Robust to Generalized Synthetic Control Estimator
set.seed(1234)

gsynth_dat <- dat %>% 
  drop_na(turnout_pc, appointed)

out <- gsynth(turnout_pc ~ appointed,
              data = gsynth_dat,
              index = c("fips", "year"),
              force = "two-way",
              CV = TRUE,
              min.T0 = 7,
              se = TRUE,
              inference = "parametric",
              parallel = TRUE,
              nboots = 1000)
reg1f <- feols(turnout_pc ~ appointed | year_state + fips, cluster = "fips", data=dat)

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Main Finding that Appointing Local Election Officials Increases Voter Turnout is Robust to Generalized Synthetic Control Estimator}",
  "\\label{tab:validation_gsynth}}",
  "\\begin{tabular}{lc}",
  "\\toprule \\toprule",
  " & Voter Turnout \\\\",
  " & (1)  \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f  \\\\", out$att.avg),
  sprintf(" & (%1.3f)  \\\\[2mm]", out$est.avg[,2] ),
  "\\midrule",
  sprintf("Counties & %4.0f  \\\\", out$N),
  sprintf("Elections & %4.0f  \\\\", out$T),
  sprintf("Observations & %4.0f  \\\\", out$N*out$T),
  sprintf("Outcome Mean & %1.2f \\\\", fitstat(reg1f,"my")),
  "\\bottomrule \\bottomrule",
  "\\multicolumn{2}{p{.4\\textwidth}}{\\footnotesize Generalized synthetic control method matches treated and control counties on pretreatment voter turnout.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.26.tex"), sep="\n")


# Table A.27: Appointing Election Officials Boosts Registration Rates More when Their Duties Specifically Include Registration (Even-Year General Elections, 1996-2022)
## Prep placebo dataset
datplacebo <- dat %>% 
  mutate(appointedXreg_separate = appointed*reg_separate,
         year_state_regsep= paste0(year_state, reg_separate),
         year_state_demvs_regsep = paste0(year_state_demvs, reg_separate),
         year_state_pop_regsep = paste0(year_state_pop, reg_separate),
         fips_regsep = paste0(fips, reg_separate))

## Run regressions
rego7ca <- feols(reg_pc ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, state == "California"))
rego7ga <- feols(reg_pc ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, state == "Georgia"))
rego7mn <- feols(reg_pc ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, state == "Minnesota"))
rego7tx <- feols(reg_pc ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, state == "Texas"))
regplacebox <- feols(reg_pc ~ appointed +  appointedXreg_separate | year_state_regsep + fips_regsep, cluster = "fips_regsep", data=datplacebo)

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Appointing Election Officials Boosts Registration Rates More when Their Duties Specifically Inlcude Registration (Even-Year General Elections, 1996-2022)}",
  "\\label{tab:state_reg}}",
  "\\begin{tabular}{lccccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{5}{c}{Registration Rate} \\\\",
  " & (1) & (2) & (3) & (4) & (5) \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f   \\\\", rego7ca$coefficients[1], rego7ga$coefficients[1], rego7mn$coefficients[1], rego7tx$coefficients[1], regplacebox$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f)    \\\\[2mm]", rego7ca$se[1], rego7ga$se[1], rego7mn$se[1], rego7tx$se[1], regplacebox$se[1]),
  sprintf("Appointed X Separate Reg &  & & &  & %1.3f   \\\\", regplacebox$coefficients[2]),
  sprintf(" & & &  &  & (%1.3f)    \\\\[2mm]", regplacebox$se[2]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", fitstat(rego7ca,"G"), fitstat(rego7ga,"G"), fitstat(rego7mn,"G"), fitstat(rego7tx,"G"), fitstat(regplacebox,"G")),
  sprintf("Elections & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f   \\\\", rego7ca$fixef_sizes[1], rego7ga$fixef_sizes[1], rego7mn$fixef_sizes[1], rego7tx$fixef_sizes[1], regplacebox$fixef_sizes[1]/13),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", rego7ca$nobs, rego7ga$nobs, rego7mn$nobs, rego7tx$nobs, regplacebox$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f  \\\\", fitstat(rego7ca,"my"), fitstat(rego7ga,"my"), fitstat(rego7mn,"my"), fitstat(rego7tx,"my"), fitstat(regplacebox,"my")),
  "State & CA & GA & MN & TX & Pooled \\\\",
  "County FEs & Yes & Yes & Yes & Yes & Yes   \\\\",
  "Year FEs & Yes & Yes & Yes & Yes & No \\\\",
  "Year x State x Sep Reg FEs & No & No & No & No & Yes \\\\",
  "Reg Switch & Yes & No & Yes & Yes & $-$ \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{6}{p{.8\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses. Individual regressions are run on states with at least 10 treated counties. ``Sep Reg'' is short for a separate registration dummy.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.27.tex"), sep="\n")


# Table A.28: Appointments, Rather than Partisanship, Drive the Effects on Voter Turnout (Even-Year General Elections, 1968-2022)
reg2 <- feols(turnout_pc ~ appointed + partisan_admin | year_state + fips, cluster = "fips", data=dat)
reg2a <- feols(turnout_pc ~ appointed + partisan_admin | year_state_demvs + fips, cluster = "fips", data=dat)
reg2b <- feols(turnout_pc ~ appointed + partisan_admin | year_state_pop + fips, cluster = "fips", data=dat)

cat(
  "\\begin{table}[h!]",
  "\\centering", 
  "\\caption{\\textbf{Appointments, Rather than Partisanship, Drive the Effects on Voter Turnout (Even-Year General Elections, 1968-2022)}",
  "\\label{tab:partisanship_citizen_participation}}",
  "\\begin{tabular}{lccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{3}{c}{Voter Turnout} \\\\",
  " & (1) & (2) & (3)  \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f  \\\\", reg2$coefficients[1], reg2a$coefficients[1], reg2b$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", reg2$se[1], reg2a$se[1], reg2b$se[1]),
  sprintf("Partisan Elected & %1.3f & %1.3f & %1.3f  \\\\", reg2$coefficients[2], reg2a$coefficients[2], reg2b$coefficients[2]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", reg2$se[2], reg2a$se[2], reg2b$se[2]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f \\\\", fitstat(reg2,"G"), fitstat(reg2a,"G"), fitstat(reg2b,"G")),
  sprintf("Elections & %4.0f & %4.0f & %4.0f  \\\\", reg2$fixef_sizes[1]/13, reg2a$fixef_sizes[1]/52, reg2b$fixef_sizes[1]/52),
  sprintf("Observations & %4.0f & %4.0f & %4.0f \\\\", reg2$nobs, reg2a$nobs, reg2b$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f \\\\", fitstat(reg2,"my"), fitstat(reg2a,"my"), fitstat(reg2b,"my")),
  "County FEs & Yes & Yes & Yes  \\\\",
  "Year x State FEs & Yes & No & No \\\\",
  "Year x State x Dem vs FEs & No & Yes & No  \\\\",
  "Year x State x Pop FEs & No & No & Yes \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{4}{p{.5\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses. The omitted category is selection through nonpartisan elections.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.28.tex"), sep="\n")


# Table A.29: Appointed Local Election Officials Do Not Clearly Benefit The Party That Appoints Them (County-Level Shifts in AZ and PA, 2000-2022)
county_partisan <- read.csv("../raw_data/county_partisan.csv")

regpc <- feols(dem_vs_pres ~ dem_control | year_state + fips, cluster = "fips", data=county_partisan)
regpca <- feols(dem_vs_pres ~ dem_control| year_state + fips[year], cluster = "fips", data=county_partisan)
regpc1 <- feols(dem_vs_gov ~ dem_control | year_state + fips, cluster = "fips", data=county_partisan)
regpca1a <- feols(dem_vs_gov ~ dem_control | year_state + fips[year], cluster = "fips", data=county_partisan)
regpc4 <- feols(dem_reg_share ~ dem_control | year_state + fips, cluster = "fips", data=county_partisan)
regpc4a <- feols(dem_reg_share ~ dem_control | year_state + fips[year], cluster = "fips", data=county_partisan)

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Appointed Local Election Officials Do Not Clearly Benefit The Party That Appoints Them (County-Level Shifts in AZ and PA, 2000-2022)}",
  "\\label{tab:partisan_county}}",
  "\\begin{tabular}{lcccccc}",
  "\\toprule \\toprule",
  "  & \\multicolumn{2}{c}{Dem pres vote share}  & \\multicolumn{2}{c}{Dem gov vote share}  & \\multicolumn{2}{c}{Dem reg share}  \\\\",
  " & (1) & (2) & (3) & (4) & (5) & (6) \\\\",
  "\\midrule",
  sprintf("Dem Appointer & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f    \\\\", regpc$coefficients[1], regpca$coefficients[1], regpc1$coefficients[1],  regpca1a$coefficients[1], regpc4$coefficients[1], regpc4a$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f)   \\\\[2mm]", regpc$se[1], regpca$se[1], regpc1$se[1], regpca1a$se[1], regpc4$se[1], regpc4a$se[1]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f  & %4.0f & %4.0f & %4.0f  & %4.0f   \\\\", fitstat(regpc,"G"), fitstat(regpca,"G"), fitstat(regpc1,"G"), fitstat(regpca1a,"G"), fitstat(regpc4,"G"), fitstat(regpc4a,"G")),
  sprintf("Elections & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f    \\\\", regpc$fixef_sizes[1]/2, regpca$fixef_sizes[1]/2, regpc1$fixef_sizes[1]/2, regpca1a$fixef_sizes[1]/2, regpc4$fixef_sizes[1]/2, regpc4a$fixef_sizes[1]/2),
  sprintf("Observations & %4.0f & %4.0f  & %4.0f & %4.0f & %4.0f  & %4.0f   \\\\", regpc$nobs, regpca$nobs, regpc1$nobs, regpca1a$nobs, regpc4$nobs, regpc4a$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f    \\\\", fitstat(regpc,"my"), fitstat(regpca,"my"), fitstat(regpc1,"my"), fitstat(regpca1a,"my"), fitstat(regpc4,"my"), fitstat(regpc4a,"my")),
  "County FEs & Yes & Yes  & Yes & Yes & Yes  & Yes  \\\\",
  "Year x State FEs & Yes & Yes & Yes & Yes & Yes & Yes   \\\\",
  "County Time Trend & No & Yes & No & Yes & No & Yes   \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{7}{p{.9\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses. Columns 1–4 use Leip's Atlas of U.S. elections. Columns 5-6 use an original data collection from each state's administrative records. Dem Appointer means that the appointing authority of the local election official has a Democratic majority.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.29.tex"), sep="\n")


# Table A.30: Appointing Local Election Officials Has A Similar Effect In Democratic- and Republican-Leaning Counties (Even-Year General Elections, 1968-2022)
regpart1 <- feols(turnout_pc ~ appointed + appointedxdem | year_state_dem + fips, cluster = "fips_dem", data=dat)
regpart2 <- feols(turnout_pc ~ appointed + appointedxdem | year_state_demvs + fips, cluster = "fips_dem", data=dat)
regpart3 <- feols(turnout_pc ~ appointed + appointedxdem | year_state_pop_dem + fips, cluster = "fips_dem", data=dat)
regpart4 <- feols(reg_pc ~ appointed + appointedxdem | year_state_dem + fips, cluster = "fips_dem", data=filter(dat, reg_separate == 0))
regpart5 <- feols(reg_pc ~ appointed + appointedxdem | year_state_demvs + fips, cluster = "fips_dem", data=filter(dat, reg_separate == 0))
regpart6 <- feols(reg_pc ~ appointed + appointedxdem | year_state_pop_dem + fips, cluster = "fips_dem", data=filter(dat, reg_separate == 0))

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Appointing Local Election Officials Has A Similar Effect In Democratic- and Republican-Leaning Counties (Even-Year General Elections, 1968-2022)}",
  "\\label{tab:citizen_participation_part}}",
  "\\begin{tabular}{lcccccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{3}{c}{Voter Turnout} & \\multicolumn{3}{c}{Registration Rate}\\\\",
  " & (1) & (2) & (3) & (4) & (5) & (6) \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", regpart1$coefficients[1], regpart2$coefficients[1], regpart3$coefficients[1], regpart4$coefficients[1], regpart5$coefficients[1], regpart6$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f)  \\\\[2mm]", regpart1$se[1], regpart2$se[1], regpart3$se[1], regpart4$se[1], regpart5$se[1], regpart6$se[1]),
  sprintf("Appointed X Democratic County & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", regpart1$coefficients[2], regpart2$coefficients[2], regpart3$coefficients[2], regpart4$coefficients[2], regpart5$coefficients[2], regpart6$coefficients[2]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f)  \\\\[2mm]", regpart1$se[2], regpart2$se[2], regpart3$se[2], regpart4$se[2], regpart5$se[2], regpart6$se[2]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", fitstat(regpart1,"G"), fitstat(regpart2,"G"), fitstat(regpart3,"G"), fitstat(regpart4,"G"), fitstat(regpart5,"G"), fitstat(regpart6,"G")),
  sprintf("Elections & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", regpart1$fixef_sizes[1]/26, regpart2$fixef_sizes[1]/52, regpart3$fixef_sizes[1]/104, regpart4$fixef_sizes[1]/22, regpart5$fixef_sizes[1]/44, regpart6$fixef_sizes[1]/88),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", regpart1$nobs, regpart2$nobs, regpart3$nobs, regpart4$nobs, regpart5$nobs, regpart6$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f \\\\", fitstat(regpart1,"my"), fitstat(regpart2,"my"), fitstat(regpart3,"my"), fitstat(regpart4,"my"), fitstat(regpart5,"my"), fitstat(regpart6,"my")),
  "County FEs & Yes & Yes & Yes & Yes & Yes & Yes \\\\",
  "Year x State x Dem FEs & Yes & No & No & Yes & No & No  \\\\",
  "Year x State x Dem vs FEs & No & Yes & No & No & Yes & No  \\\\",
  "Year x State x Pop x Dem FEs & No & No & Yes & No & No & Yes \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{7}{p{.95\\textwidth}}{\\footnotesize Democratic counties rank in the top half in pre-treatment presidential Democratic vote share compared to other counties within the same state. Robust standard errors clustered by county in parentheses. The number of observations is smaller in columns 3-4 because Arizona and Georgia are excluded and because turnout data is available from 1968 but registration data is only available from 1996.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.30.tex"), sep="\n")


# Table A.31: Appointed Election Officials Were More Likely to Apply For CTCL Funding In 2020
ctcl_dat <- read_dta("../raw_data/ctcl.dta") %>%
  filter(policy_year == 2020) %>% 
  select(fips, year = policy_year, treat, lag_vs_dem4_pres, med_income2019, metro, share_white_nh, covid_death_rate, soc_dist, naco, dem_clerk) %>% 
  right_join(read.csv("../raw_data/dat_extended.csv") %>% filter(year == 2020), by = c("fips", "year")) %>% 
  left_join(read.csv("../raw_data/nhgis0009_ds248_2020_county.csv") %>% 
              rename(fips = GEOCODE,
                     total_pop = U7B001) %>% 
              select(fips, total_pop), by = "fips") %>% 
  mutate(total_pop_squared = total_pop^2,
         log_pop = log(total_pop),
         log_pop_squared = log_pop^2,
         dem_vs_pres_squared = dem_vs_pres^2,
         log_med_income = log(med_income2019)) %>% 
  select(fips, year, state, treat, appointed, log_pop, log_pop_squared, dem_vs_pres, lag_vs_dem4_pres, log_med_income, metro, share_white_nh, covid_death_rate, soc_dist, naco) %>% 
  filter(!is.na(treat))

regctcl0 <- feols(treat ~ appointed   | state, cluster = "state", data=ctcl_dat)
regctcl1 <- feols(treat ~ appointed + lag_vs_dem4_pres  | state, cluster = "state", data=ctcl_dat)
regctcl2 <- feols(treat ~ appointed + lag_vs_dem4_pres + log_pop + log_med_income  | state, cluster = "state", data=ctcl_dat)
regctcl3 <- feols(treat ~ appointed + lag_vs_dem4_pres + log_pop + log_med_income + metro + share_white_nh  | state, cluster = "state", data=ctcl_dat)
regctcl4 <- feols(treat ~ appointed + lag_vs_dem4_pres + log_pop + log_med_income + metro + share_white_nh + covid_death_rate +  soc_dist | state, cluster = "state", data=ctcl_dat)
regctcl5 <- feols(treat ~ appointed + lag_vs_dem4_pres + log_pop + log_med_income + metro + share_white_nh + covid_death_rate +  soc_dist + naco | state, cluster = "state", data=ctcl_dat)

cat(
  "\\begin{table}[h!]",
  "\\centering", 
  "\\caption{\\textbf{Appointed Election Officials Were More Likely to Apply For CTCL Funding In 2020}",
  "\\label{tab:ctcl_apply}}",
  "\\begin{tabular}{lcccccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{6}{c}{Applied for CTCL Funding} \\\\",
  " & (1) & (2) & (3) & (4) & (5) & (6)  \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f &  %1.3f & %1.3f &  %1.3f & %1.3f  \\\\", regctcl0$coefficients[1], regctcl1$coefficients[1], regctcl2$coefficients[1], regctcl3$coefficients[1], regctcl4$coefficients[1], regctcl5$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f)  \\\\[2mm]", regctcl0$se[1], regctcl1$se[1], regctcl2$se[1], regctcl3$se[1], regctcl4$se[1], regctcl5$se[1]),
  sprintf("Lag dem vote share &  & %1.3f &  %1.3f & %1.3f &  %1.3f & %1.3f \\\\", regctcl1$coefficients[2], regctcl2$coefficients[2], regctcl3$coefficients[2], regctcl4$coefficients[2], regctcl5$coefficients[2]),
  sprintf(" & & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regctcl1$se[2], regctcl2$se[2], regctcl3$se[2], regctcl4$se[2], regctcl5$se[2]),
  sprintf("Log(Population) &  &  &  %1.3f & %1.3f &  %1.3f & %1.3f  \\\\",  regctcl2$coefficients[3], regctcl3$coefficients[3], regctcl4$coefficients[3], regctcl5$coefficients[3]),
  sprintf(" &  &  & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regctcl2$se[3], regctcl3$se[3], regctcl4$se[3], regctcl5$se[3]),
  sprintf("Log(Median income) &  & &  %1.3f & %1.3f &  %1.3f & %1.3f \\\\",  regctcl2$coefficients[4], regctcl3$coefficients[4], regctcl4$coefficients[4], regctcl5$coefficients[4]),
  sprintf(" &  &  & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regctcl2$se[4], regctcl3$se[4], regctcl4$se[4], regctcl5$se[4]),
  sprintf("Metro &  &  &  & %1.3f &  %1.3f & %1.3f \\\\", regctcl3$coefficients[5], regctcl4$coefficients[5], regctcl5$coefficients[5]),
  sprintf(" &  &  & & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regctcl3$se[5], regctcl4$se[5], regctcl5$se[5]),
  sprintf("Non-Hisp white share &  &  &  & %1.3f &  %1.3f & %1.3f \\\\", regctcl3$coefficients[6], regctcl4$coefficients[6], regctcl5$coefficients[6]),
  sprintf(" &  &  &  & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regctcl3$se[6], regctcl4$se[6], regctcl5$se[6]),
  sprintf("COVID death rate &  &  &   & &  %1.3f & %1.3f \\\\", regctcl4$coefficients[7], regctcl5$coefficients[7]),
  sprintf(" &  & &  &  & (%1.3f) & (%1.3f) \\\\[2mm]", regctcl4$se[7], regctcl5$se[7]),
  sprintf("Social distancing share  &  &  &   & &  %1.3f & %1.3f  \\\\", regctcl4$coefficients[8], regctcl5$coefficients[8]),
  sprintf(" &  & &  &  & (%1.3f) & (%1.3f)  \\\\[2mm]", regctcl4$se[8], regctcl5$se[8]),
  sprintf("NACo &  &  &  &  &   & %1.3f \\\\", regctcl5$coefficients[9]),
  sprintf(" &  &  & &  &  & (%1.3f) \\\\[2mm]", regctcl5$se[9]),
  "\\midrule",
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", regctcl0$nobs, regctcl1$nobs, regctcl2$nobs, regctcl3$nobs, regctcl4$nobs, regctcl5$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f \\\\", fitstat(regctcl0,"my"), fitstat(regctcl1,"my"), fitstat(regctcl2,"my"), fitstat(regctcl3,"my"), fitstat(regctcl4,"my"), fitstat(regctcl5,"my")),
  "State FEs & Yes & Yes & Yes & Yes & Yes & Yes \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{7}{p{.9\\textwidth}}{\\footnotesize Robust standard errors clustered by state in parentheses. Center for Tech and Civil Life grant and covariate data is from Lal and Thompson (2024). Population is the voting-age population. Median Income is median household income measured with the 5-year ACS ending in 2019. Metro is an indicator for urban and suburban counties based on the Census nine-value urban–rural continuum. Non-Hisp White Share is the share of residents who are classified as non-Hispanic White in the 2020 census. COVID death rate is the number of deaths per 1,000 residents prior to September 1, 2020. Social Distancing Share is the share of Nationscape respondents in the county who report always complying with recommended social distancing in the early fall of 2020. NACo is an indicator for county membership in the National Association of Counties.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.31.tex"), sep="\n")


# Table A.32: Additional Election Expenditures Increases Voter Turnout (Even-Year General Elections, 2004-2016)
regcostflippedreg <- feols(turnout_pc ~ log_expnd_per_reg | year_state + fips, cluster = "fips", data=dat)
regcostflippedrega <- feols(turnout_pc ~ log_expnd_per_reg | year_state_demvs + fips, cluster = "fips", data=dat)
regcostflippedregb <- feols(turnout_pc ~ log_expnd_per_reg | year_state_pop + fips, cluster = "fips", data=dat)
regcostflippedregx <- feols(turnout_pc ~ log_expnd_per_reg*small | year_state_small + fips, cluster = "fips", data=dat)
regcostflippedregax <- feols(turnout_pc ~ log_expnd_per_reg*small | year_state_demvs_small + fips, cluster = "fips", data=dat)
regcostflippedregbx <- feols(turnout_pc ~ log_expnd_per_reg*small  | year_state_pop + fips, cluster = "fips", data=dat)

cat(
  "\\begin{table}[h!]",
  "\\centering", 
  "\\caption{\\textbf{Additional Election Expenditures Increases Voter Turnout (Even-Year General Elections, 2004-2016)}",
  "\\label{tab:election_costs_turnout}}",
  "\\begin{tabular}{lcccccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{6}{c}{Voter Turnout)} \\\\",
  " & (1) & (2) & (3) & (4) & (5) & (6) \\\\",
  "\\midrule",
  sprintf("Ln expend per reg & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", regcostflippedreg$coefficients[1], regcostflippedrega$coefficients[1], regcostflippedregb$coefficients[1], regcostflippedregx$coefficients[1], regcostflippedregax$coefficients[1], regcostflippedregbx$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regcostflippedreg$se[1], regcostflippedrega$se[1], regcostflippedregb$se[1], regcostflippedregx$se[1], regcostflippedregax$se[1], regcostflippedregbx$se[1]),
  sprintf("Ln expend per reg X Small County &  &  &  & %1.3f & %1.3f & %1.3f  \\\\", regcostflippedregx$coefficients[2], regcostflippedregax$coefficients[2], regcostflippedregbx$coefficients[2]),
  sprintf(" &  &  &  & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regcostflippedregx$se[2], regcostflippedregax$se[2], regcostflippedregbx$se[2]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", fitstat(regcostflippedreg,"G"), fitstat(regcostflippedrega,"G"), fitstat(regcostflippedregb,"G"), fitstat(regcostflippedregx,"G"), fitstat(regcostflippedregax,"G"), fitstat(regcostflippedregbx,"G")),
  sprintf("Elections & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", floor(regcostflippedreg$fixef_sizes[1]/7), floor(regcostflippedrega$fixef_sizes[1]/28), floor(regcostflippedregb$fixef_sizes[1]/28), floor(regcostflippedregx$fixef_sizes[1]/14), regcostflippedregax$fixef_sizes[1]/56, floor(regcostflippedregbx$fixef_sizes[1]/28)),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", regcostflippedreg$nobs, regcostflippedrega$nobs, regcostflippedregb$nobs, regcostflippedregx$nobs, regcostflippedregax$nobs, regcostflippedregbx$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f \\\\", fitstat(regcostflippedreg,"my"), fitstat(regcostflippedrega,"my"), fitstat(regcostflippedregb,"my"), fitstat(regcostflippedregx,"my"), fitstat(regcostflippedregax,"my"), fitstat(regcostflippedregbx,"my")),
  "County FEs & Yes & Yes & Yes & Yes & Yes & Yes \\\\",
  "Year x State FEs & Yes & No & No & No & No & No  \\\\",
  "Year x State x Dem vs FEs & No & Yes & No & No & No & No  \\\\",
  "Year x State x Pop FEs & No & No & Yes & No & No & Yes  \\\\",
  "Year x State x Small FEs & No & No & No & Yes & No & No  \\\\",
  "Year x State x Dem vs x Small FEs & No & No & No & No & Yes & No \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{7}{p{1\\textwidth}}{\\footnotesize Ln expend per reg is the natural log of total yearly election expenditures per registered voter. Small counties rank in the bottom half in population compared to other counties within the same state. Robust standard errors clustered by county in parentheses. Data is from Mohr et al. (2018) and is available for Arizona, California, Georgia, Minnesota, Missouri, Nebraska, and Nevada. Elections are the average number of elections included for each state, rounded down to the nearest interger. Expenditure data is normalized to 2020 dollars.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.32.tex"), sep="\n")

## "A doubling of expenditures per registrant increases voter turnout by 0.27 percentage points on average,
## and 0.39 percentage points in smaller counties."
regcostflippedreg$coefficients[1]*log(2)*100
(regcostflippedregx$coefficients[1] + regcostflippedregx$coefficients[2])*log(2)*100


# Table A.33: Comparison of Administrative Outcomes Between Appointed and Directly Elected Local Election Officials (Even-Year General, 2000-2022)
regp1f <- feols(eavs_polling_places_per1k ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, fips != 48301)) # Remove Loving, TX
regp2f <- feols(prov_rate ~ appointed | year_state + fips, cluster = "fips", data=dat)
regp3f <- feols(prov_rejection_rate ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, fips != 48301))
regp4f <- feols(eavs_absentee_rej_rate ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, fips != 48301))
regp5f <- feols(eavs_reg_removal_rate ~ appointed | year_state + fips, cluster = "fips", data=filter(dat, fips != 48301))

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Comparison of Administrative Outcomes Between Appointed and Directly Elected Local Election Officials (Even-Year General, 2000-2022)}",
  "\\label{tab:policy_full}}",
  "\\begin{tabular}{lccccc}",
  "\\toprule \\toprule",
  " & Polling & Prov & Prov & Absentee & Reg  \\\\",
  " & Places & Share & Rejection & Rejection & Removal \\\\",
  " & (1) & (2) & (3) & (4) & (5) \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", regp1f$coefficients[1], regp2f$coefficients[1], regp3f$coefficients[1], regp4f$coefficients[1], regp5f$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f)  \\\\[2mm]", regp1f$se[1], regp2f$se[1], regp3f$se[1], regp4f$se[1], regp5f$se[1]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", fitstat(regp1f,"G"), fitstat(regp2f,"G"), fitstat(regp3f,"G"), fitstat(regp4f,"G"), fitstat(regp5f,"G")),
  sprintf("Elections (avg) & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", regp1f$fixef_sizes[1]/13, regp2f$fixef_sizes[1]/13, regp3f$fixef_sizes[1]/13, regp4f$fixef_sizes[1]/13, regp5f$fixef_sizes[1]/13),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", regp1f$nobs, regp2f$nobs, regp3f$nobs, regp4f$nobs, regp5f$nobs),
  sprintf("Outcome Mean & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", fitstat(regp1f,"my"), fitstat(regp2f,"my"), fitstat(regp3f,"my"), fitstat(regp4f,"my"), fitstat(regp5f,"my")),
  "County FEs & Yes & Yes & Yes & Yes & Yes  \\\\",
  "Year x State  & Yes & Yes & Yes & Yes & Yes  \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{6}{p{.75\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses. Columns 1 through 5 use EAVS survey data from the US Election Assistance Commission. Column 1 measures the number of polling places per 1,000 residents, column 2 the share of votes cast provisionally, column 3 the share of provisional ballots rejected, column 4 the share of absentee ballots rejected, and column 5 the share of registrants removed from the list.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.33.tex"), sep="\n")


# Table A.34: Appointed Local Election Officials May Be More Likely To Maintain Official Social Media Accounts
datcom <- left_join(dat, read.csv("../raw_data/nhgis0009_ds248_2020_county.csv") %>% 
                      rename(fips = GEOCODE,
                             total_pop = U7B001) %>% 
                      select(fips, total_pop), by= "fips") %>% 
  mutate(total_pop_squared = total_pop^2,
         log_pop = log(total_pop),
         log_pop_squared = log_pop^2) %>% 
  filter(year == 2022)

regcom <- feols(has_social ~ appointed  + log_pop + log_pop_squared | state, cluster = "state", data=datcom)
regcoma <- feols(has_fb ~ appointed  + log_pop + log_pop_squared | state, cluster = "state", data=datcom)
regcomb <- feols(has_twitter ~ appointed  + log_pop + log_pop_squared | state, cluster = "state", data=datcom)
regcomc <- feols(has_insta ~ appointed  + log_pop + log_pop_squared | state, cluster = "state", data=datcom)
regcomd <- feols(has_tiktok ~ appointed  + log_pop + log_pop_squared | state, cluster = "state", data=datcom)

cat(
  "\\begin{table}[h!]",
  "\\centering", 
  "\\caption{\\textbf{Appointed Local Election Officials May Be More Likely To Maintain Official Social Media Accounts}",
  "\\label{tab:comms}}",
  "\\begin{tabular}{lccccc}",
  "\\toprule \\toprule",
  " & Has social media & Has FB & Has X & Has Insta & Has Tiktok \\\\",
  " & (1) & (2) & (3) & (4) & (5) \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", regcom$coefficients[1], regcoma$coefficients[1], regcomb$coefficients[1], regcomc$coefficients[1], regcomd$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f)  \\\\[2mm]", regcom$se[1], regcoma$se[1], regcomb$se[1], regcomc$se[1], regcomd$se[1]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", fitstat(regcom,"G"), fitstat(regcoma,"G"), fitstat(regcomb,"G"), fitstat(regcomc,"G"), fitstat(regcomd,"G")),
  sprintf("States & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f   \\\\", regcom$fixef_sizes[1], regcoma$fixef_sizes[1], regcomb$fixef_sizes[1], regcomc$fixef_sizes[1], regcomd$fixef_sizes[1]),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", regcom$nobs, regcoma$nobs, regcomb$nobs, regcomc$nobs, regcomd$nobs),
  sprintf("Outcome Mean & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", fitstat(regcom,"my"), fitstat(regcoma,"my"), fitstat(regcomb,"my"), fitstat(regcomc,"my"), fitstat(regcomd,"my")),
  "County FEs & Yes & Yes & Yes & Yes & Yes  \\\\",
  "Year x State FEs & Yes & Yes & Yes & Yes & Yes \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{6}{p{.85\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses. Election official social media data is provided by Thessalia Merivaki and Mara Suttmann-Lea.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.34.tex"), sep="\n")


# Table A.35: Appointed and Elected Local Election Officials Possess Less Experience in Elections But Are More Professionalized
## Run lines 126--199 above first
regmod0 <- feols(prior_experience ~ appointed  + log_pop + log_pop_squared | state, cluster = "state", data=reed_dat, weights = reed_dat$weight) 
regmod3 <- feols(as.numeric(memberships) ~ appointed  + log_pop + log_pop_squared | state, cluster = "state", data=reed_dat, weights = reed_dat$weight) 
regmod4 <- feols(other_leo ~ appointed  + log_pop + log_pop_squared | state, cluster = "state", data=reed_dat, weights = reed_dat$weight) 
regmod5 <- feols(OTHERLEOCOUNT ~ appointed  + log_pop + log_pop_squared | state, cluster = "state", data=reed_dat, weights = reed_dat$weight)
regmod6 <- feols(FTE ~ appointed  + log_pop + log_pop_squared | state, cluster = "state", data=reed_dat, weights = reed_dat$weight)
regmod7 <- feols(over_65 ~ appointed  + log_pop + log_pop_squared | state, cluster = "state", data=reed_dat, weights = reed_dat$weight)
regmod8 <- feols(salary ~ appointed  + log_pop + log_pop_squared | state, cluster = "state", data=reed_dat, weights = reed_dat$weight)

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Appointed and Elected Local Election Officials Possess Less Experience in Elections But Are More Professionalized}",
  "\\label{tab:reed_dat}}",
  "\\begin{tabular}{lccccccc}",
  "\\toprule \\toprule",
  " & Previous & Professional & Served & Number & Age  & Salary & FTEs  \\\\",
  " & Experience & Memberships & Elsewhere & Served &  $>$65$+$ & & \\\\",
  " & (1) & (2) & (3) & (4) & (5) & (6) & (7)  \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  & %1.3f & %1.3f \\\\", regmod0$coefficients[1], regmod3$coefficients[1], regmod4$coefficients[1], regmod5$coefficients[1], regmod7$coefficients[1], regmod8$coefficients[1], regmod6$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f)  \\\\[2mm]", regmod0$se[1], regmod3$se[1], regmod4$se[1], regmod5$se[1], regmod7$se[1], regmod8$se[1], regmod6$se[1]),
  "\\midrule",
  sprintf("States & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f   \\\\", regmod0$fixef_sizes, regmod3$fixef_sizes, regmod4$fixef_sizes, regmod5$fixef_sizes, regmod7$fixef_sizes, regmod8$fixef_sizes, regmod6$fixef_sizes),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", regmod0$nobs, regmod3$nobs, regmod4$nobs, regmod5$nobs, regmod7$nobs, regmod8$nobs, regmod6$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f   \\\\", fitstat(regmod0,"my"), fitstat(regmod3,"my"), fitstat(regmod4,"my"), fitstat(regmod5,"my"), fitstat(regmod7,"my"), fitstat(regmod8,"my"), fitstat(regmod6,"my")),
  "State FEs & Yes & Yes & Yes & Yes & Yes  & Yes & Yes    \\\\",
  "Log Pop & Yes & Yes & Yes & Yes & Yes & Yes & Yes  \\\\",
  "Log Pop squared & Yes & Yes & Yes & Yes & Yes & Yes & Yes   \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{8}{p{1.05\\textwidth}}{\\footnotesize Robust standard errors clustered by state in parentheses. Data is from the 2020 EVIC Survey of Local Election Officials and is filtered to only include chief local election officials. County is imputed from zip code to calculate population controls. Observations are weighted to be representative of the population of local election officials. Column 1 measures years of previous experience in election administration, calculated by subtracting current tenure length from total experience working in the field. Column 2 sums the number of professional memberships among the following four organizations: state association of local election officials, regional and/or local association of election officials, the Election Center (National Association of Election Officials), and the International Association of Government Officials (iGO). Column 3 measures whether clerks have served as election officials in other jurisdictions and column 4 measures the total number of other jurisdictions served in. Column 5 is a binary for whether the election official is over the age of 65 or not. Column 6 measures salary in dollars, which is dervied by taking the midpoint values of salary ranges. Column 7 measures full-time equivalents, which is derived by taking the midpoint values of FTE ranges.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.35.tex"), sep="\n")


# Table A.36: Presence of a Daily Local Newspaper Attenuates the Effect of Appointing Local Election Officials on Citizen Participation (Even-Year General Elections, 1968-2022)
regnews1a <- feols(turnout_pc ~ appointed + appointedXnews_alt | year_state_news_alt + fips, cluster = "fips_news_alt", data=dat)
regnews2a <- feols(turnout_pc ~ appointed + appointedXnews_alt | year_state_demvs_news_alt + fips, cluster = "fips_news_alt", data=dat)
regnews3a <- feols(turnout_pc ~ appointed + appointedXnews_alt | year_state_pop_news_alt + fips, cluster = "fips_news_alt", data=dat)
regnews1fa <- feols(reg_pc ~ appointed + appointedXnews_alt | year_state_news_alt + fips, cluster = "fips_news_alt", data=filter(dat, reg_separate == 0))
regnews2fa <- feols(reg_pc ~ appointed + appointedXnews_alt | year_state_demvs_news_alt + fips, cluster = "fips_news_alt", data=filter(dat, reg_separate == 0))
regnews3fa <- feols(reg_pc ~ appointed + appointedXnews_alt | year_state_pop_news_alt + fips, cluster = "fips_news_alt", data=filter(dat, reg_separate == 0))

cat(
  "\\begin{table}[h]",
  "\\centering", 
  "\\caption{\\textbf{Presence of a Daily Local Newspaper Attenuates the Effect of Appointing Local Election Officials on Citizen Participation (Even-Year General Elections, 1968-2022)}",
  "\\label{tab:citizen_participation_news_alt}}",
  "\\begin{tabular}{lcccccc}",
  "\\toprule \\toprule",
  " & \\multicolumn{3}{c}{Voter Turnout} & \\multicolumn{3}{c}{Registration Rate}\\\\",
  " & (1) & (2) & (3) & (4) & (5) & (6) \\\\",
  "\\midrule",
  sprintf("Appointed & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", regnews1a$coefficients[1], regnews2a$coefficients[1], regnews3a$coefficients[1], regnews1fa$coefficients[1], regnews2fa$coefficients[1], regnews3fa$coefficients[1]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regnews1a$se[1], regnews2a$se[1], regnews3a$se[1], regnews1fa$se[1], regnews2fa$se[1], regnews3fa$se[1]),
  sprintf("Appointed X Newspaper & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f & %1.3f  \\\\", regnews1a$coefficients[2], regnews2a$coefficients[2], regnews3a$coefficients[2], regnews1fa$coefficients[2], regnews2fa$coefficients[2], regnews3fa$coefficients[2]),
  sprintf(" & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) & (%1.3f) \\\\[2mm]", regnews1a$se[2], regnews2a$se[2], regnews3a$se[2], regnews1fa$se[2], regnews2fa$se[2], regnews3fa$se[2]),
  "\\midrule",
  sprintf("Counties & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", fitstat(regnews1a,"G"), fitstat(regnews2a,"G"), fitstat(regnews3a,"G"), fitstat(regnews1fa,"G"), fitstat(regnews2fa,"G"), fitstat(regnews3fa,"G")),
  sprintf("Elections & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f  \\\\", regnews1a$fixef_sizes[1]/26, regnews2a$fixef_sizes[1]/104, 14, regnews1fa$fixef_sizes[1]/22, regnews2fa$fixef_sizes[1]/88, 7),
  sprintf("Observations & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f & %4.0f \\\\", regnews1a$nobs, regnews2a$nobs, regnews3a$nobs, regnews1fa$nobs, regnews2fa$nobs, regnews3fa$nobs),
  sprintf("Outcome Mean & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f & %1.2f \\\\", fitstat(regnews1a,"my"), fitstat(regnews2a,"my"), fitstat(regnews3a,"my"), fitstat(regnews1fa,"my"), fitstat(regnews2fa,"my"), fitstat(regnews3fa,"my")),
  "County FEs & Yes & Yes & Yes & Yes & Yes & Yes \\\\",
  "Year x State x Newspaper FEs & Yes & No & No & Yes & No & No  \\\\",
  "Year x State x Dem vs x Newspaper FEs & No & Yes & No & No & Yes & No \\\\",
  "Year x State x Pop x Newspaper FEs & No & No & Yes & No & No & Yes \\\\",
  "\\bottomrule \\bottomrule",
  "\\multicolumn{7}{p{1.05\\textwidth}}{\\footnotesize Robust standard errors clustered by county in parentheses. The number of observations is smaller in columns 4-6 because Arizona and Georgia are excluded and because turnout data is available from 1968 but registration data is only available from 1996.}",
  "\\end{tabular}",
  "\\end{table}",
  file=paste0(path, "/../output/tables/Table_A.36.tex"), sep="\n")

## "Correcting for guessing, only 17.2% of respondents were able to correctly identify
## the title of their chief election official. Only 5.2% of respondents knew whether their
## election official is elected or appointed. And fewer than 8% of respondents correctly identified
## their election official out of a list of five names.

leo_knowledge <- read.csv("../raw_data/leo_survey_knowledge.csv")
dat.weighted <- svydesign(ids = ~1, data = leo_knowledge, weights = leo_knowledge$weight)

prop.table(svytable(~guess_office_correct, design = dat.weighted))[2] - 
  (1 - prop.table(svytable(~guess_office_dk, design = dat.weighted))[2] -
     prop.table(svytable(~guess_office_correct, design = dat.weighted))[2])/7 # 7 question options

prop.table(svytable(~guess_selection_correct, design = dat.weighted))[2] -
  (1 - prop.table(svytable(~guess_selection_dk, design = dat.weighted))[2] -
     prop.table(svytable(~guess_selection_correct, design = dat.weighted))[2])/2 # 2 question options

prop.table(svytable(~guess_leo_correct, design = dat.weighted))[2] -
  (1 - prop.table(svytable(~guess_leo_dk, design = dat.weighted))[2] -
     prop.table(svytable(~guess_leo_correct, design = dat.weighted))[2])/5 # 5 question options